@@ -16,33 +16,32 @@
   (let ((g 1.0)
 	(Q 1.0)
 	(wc (tan (* pi fz)))
-	(c (make-float-vector (* 2 n))))
-    
-    (define (cascade->canonical A)
-      ;; (cascade->canonical A) converts cascade filter coeffs to canonical form
-      ;; from Orfanidis "Introduction to Signal Processing"
-      
-      (define (conv M h L x y)
-	;; x * h -> y
-	(do ((n 0 (+ n 1)))
-	    ((= n (+ L M)))
-	  (let ((sum 0.0)
-		(start (max 0 (- n L 1)))
-		(end (min n M)))
-	    (do ((m start (+ m 1)))
-		((> m end))
-	      (set! sum (+ sum (* (h m) (x (- n m))))))
-	    (set! (y n) sum))))
-      
-      (let ((K (length A)))
-	(let ((d (make-float-vector (+ 1 (* 2 K))))
-	      (a1 (make-float-vector (+ 1 (* 2 K)))))
-	  (set! (a1 0) 1.0)
-	  (do ((i 0 (+ i 1)))
-	      ((= i K))
-	    (conv 2 (A i) (+ 1 (* 2 i)) a1 d)
-	    (copy d a1 0 (+ 3 (* 2 i))))
-	  a1)))
+	(c (make-float-vector (* 2 n)))
+
+	(cascade->canonical 
+	 (let ((conv (lambda (M h L x y)
+		       ;; x * h -> y
+		       (do ((n 0 (+ n 1)))
+			   ((= n (+ L M)))
+			 (let ((sum 0.0)
+			       (start (max 0 (- n L 1)))
+			       (end (min n M)))
+			   (do ((m start (+ m 1)))
+			       ((> m end))
+			     (set! sum (+ sum (* (h m) (x (- n m))))))
+			   (set! (y n) sum))))))
+	   (lambda (A)
+	     ;; (cascade->canonical A) converts cascade filter coeffs to canonical form
+	     ;; from Orfanidis "Introduction to Signal Processing"
+	     (let ((K (length A)))
+	       (let ((d (make-float-vector (+ 1 (* 2 K))))
+		     (a1 (make-float-vector (+ 1 (* 2 K)))))
+		 (set! (a1 0) 1.0)
+		 (do ((i 0 (+ i 1)))
+		     ((= i K))
+		   (conv 2 (A i) (+ 1 (* 2 i)) a1 d)
+		   (copy d a1 0 (+ 3 (* 2 i))))
+		 a1))))))
     
     (do ((i 0 (+ i 2))
 	 (j 0 (+ j 3))
@@ -118,7 +117,8 @@ freq (srate = 1.0): (make-butterworth-lowpass 8 .1)"))
       (if (odd? n) (set! n (+ n 1)))
       (let ((coeffs (let ((proto (butterworth-prototype n)))
 		      (analog->digital n (car proto) (cadr proto) fc))))
-	(make-filter :xcoeffs (car coeffs) :ycoeffs (cadr coeffs))))))
+	(make-filter :xcoeffs (car coeffs) 
+		     :ycoeffs (cadr coeffs))))))
 
 (define make-butterworth-highpass
   (let ((documentation "(make-butterworth-highpass n fc) returns a highpass Butterworth filter; n = order, fc = cutoff \
@@ -127,7 +127,8 @@ freq (srate = 1.0): (make-butterworth-highpass 8 .1)"))
       (if (odd? n) (set! n (+ n 1)))
       (let ((coeffs (let ((hproto (prototype->highpass n (butterworth-prototype n))))
 		      (analog->digital n (car hproto) (cadr hproto) fc))))
-	(make-filter :xcoeffs (car coeffs) :ycoeffs (cadr coeffs))))))
+	(make-filter :xcoeffs (car coeffs) 
+		     :ycoeffs (cadr coeffs))))))
 
 (define make-butterworth-bandpass
   (let ((documentation "(make-butterworth-bandpass n fl fh) returns a bandpass Butterworth filter; n = order, fl and fh \
@@ -182,7 +183,8 @@ fc = cutoff freq (srate = 1.0): (make-chebyshev-lowpass 8 .1)"))
       (if (odd? n) (set! n (+ n 1)))
       (let ((coeffs (let ((proto (chebyshev-prototype n ripple)))
 		      (analog->digital n (car proto) (cadr proto) fc))))
-	(make-filter :xcoeffs (car coeffs) :ycoeffs (cadr coeffs))))))
+	(make-filter :xcoeffs (car coeffs) 
+		     :ycoeffs (cadr coeffs))))))
 
 (define make-chebyshev-highpass 
   (let ((documentation "(make-chebyshev-highpass n fc (ripple 1.0)) returns a highpass Chebyshev filter; n = order, \
@@ -191,7 +193,8 @@ fc = cutoff freq (srate = 1.0): (make-chebyshev-highpass 8 .1 .01)"))
       (if (odd? n) (set! n (+ n 1)))
       (let ((coeffs (let ((hproto (prototype->highpass n (chebyshev-prototype n ripple))))
 		      (analog->digital n (car hproto) (cadr hproto) fc))))
-	(make-filter :xcoeffs (car coeffs) :ycoeffs (cadr coeffs))))))
+	(make-filter :xcoeffs (car coeffs) 
+		     :ycoeffs (cadr coeffs))))))
 
 (define make-chebyshev-bandpass 
   (let ((documentation "(make-chebyshev-bandpass n fl fh (ripple 1.0)) returns a bandpass Chebyshev filter; n = order, \
@@ -244,7 +247,8 @@ fc = cutoff freq (srate = 1.0): (make-inverse-chebyshev-lowpass 10 .4 120)"))
       (if (odd? n) (set! n (+ n 1)))
       (let* ((proto (inverse-chebyshev-prototype n loss-dB))
 	     (coeffs (analog->digital n (car proto) (cadr proto) fc)))
-	(make-filter :xcoeffs (float-vector-scale! (car coeffs) (caddr proto)) :ycoeffs (cadr coeffs))))))
+	(make-filter :xcoeffs (float-vector-scale! (car coeffs) (caddr proto)) 
+		     :ycoeffs (cadr coeffs))))))
 
 (define make-inverse-chebyshev-highpass 
   (let ((documentation "(make-inverse-chebyshev-highpass n fc (loss-dB 60.0)) returns a highpass inverse-Chebyshev filter; n = order, \
@@ -254,7 +258,8 @@ fc = cutoff freq (srate = 1.0): (make-inverse-chebyshev-highpass 10 .1 120)"))
       (let* ((proto (inverse-chebyshev-prototype n loss-dB))
 	     (coeffs (let ((hproto (prototype->highpass n proto)))
 		       (analog->digital n (car hproto) (cadr hproto) fc))))
-	(make-filter :xcoeffs (float-vector-scale! (car coeffs) (caddr proto)) :ycoeffs (cadr coeffs))))))
+	(make-filter :xcoeffs (float-vector-scale! (car coeffs) (caddr proto)) 
+		     :ycoeffs (cadr coeffs))))))
 
 (define make-inverse-chebyshev-bandpass 
   (let ((documentation "(make-inverse-chebyshev-bandpass n fl fh (loss-dB 60.0)) returns a bandpass inverse-Chebyshev filter; n = order, \
@@ -277,54 +282,52 @@ fl and fh are edge freqs (srate=1.0): (make-inverse-chebyshev-bandstop 8 .1 .4 9
 
 ;;; ---------------- Bessel (-Thompson) ---------------- 
 
-(define (bessel-prototype n)
-  
-  (define (bessel-i n)
-
-    (define (fact n)
-      (do ((x 1)
-	   (i 2 (+ i 1)))
-	  ((> i n) x)
-	(set! x (* x i))))
-    ;; this form overflows if we don't have bignums
-    ;;  (define (bessel-i n)
-    ;;    (let ((cs (make-float-vector (+ n 1))))
-    ;;      (do ((i 0 (+ i 1)))
-    ;;	  ((> i n))
-    ;;	(set! (cs i) (/ (fact (- (* 2 n) i))
-    ;;			(* (expt 2 (- n i))
-    ;;			   (fact i)
-    ;;			   (fact (- n i))))))
-    ;;      cs))
-    
-    (do ((cs (make-float-vector (+ n 1)))
-	 (i 0 (+ i 1)))
-	((> i n) cs)
-      (do ((val (/ 1.0 (* (fact i) (expt 2 (- n i)))))
-	   (k 1 (+ k 1))
-	   (f (- n i -1) (+ f 1)))  ; (f (+ 1 (- n i)) (+ 1 f))
-	  ((> k n)
-	   (set! (cs i) val))   
-	(set! val (* val f)))))
-  
-  (let ((len (/ (* n 3) 2)))
-    (let ((num (make-float-vector len))
-	  (den (make-float-vector len))
-	  (b2 (bessel-i n)))
-      (let ((p (gsl-roots (copy b2 (make-vector (length b2))))))
-	(do ((i 0 (+ i 1)))
-	    ((= i n))
-	  (set! (p i) (/ (p i) (expt (b2 0) (/ 1.0 n)))))
-	(do ((j 0 (+ j 3))
-	     (i 0 (+ i 2)))
-	    ((>= i n))
-	  (set! (num    j   ) 0.0)
-	  (set! (num (+ j 1)) 0.0)
-	  (set! (num (+ j 2)) 1.0)
-	  (set! (den    j   ) 1.0)
-	  (set! (den (+ j 1)) (* -2.0 (real-part (p i))))
-	  (set! (den (+ j 2)) (real-part (* (p i) (p (+ i 1)))))))
-      (list num den))))
+(define bessel-prototype 
+  (let ((bessel-i 
+	 (let ((fact (lambda (n)
+		       (do ((x 1)
+			    (i 2 (+ i 1)))
+			   ((> i n) x)
+			 (set! x (* x i))))))
+	   ;; this form overflows if we don't have bignums
+	   ;;  (define (bessel-i n)
+	   ;;    (let ((cs (make-float-vector (+ n 1))))
+	   ;;      (do ((i 0 (+ i 1)))
+	   ;;	  ((> i n))
+	   ;;	(set! (cs i) (/ (fact (- (* 2 n) i))
+	   ;;			(* (expt 2 (- n i))
+	   ;;			   (fact i)
+	   ;;			   (fact (- n i))))))
+	   ;;      cs))
+	   (lambda (n)
+	     (do ((cs (make-float-vector (+ n 1)))
+		  (i 0 (+ i 1)))
+		 ((> i n) cs)
+	       (do ((val (/ 1.0 (* (fact i) (expt 2 (- n i)))))
+		    (k 1 (+ k 1))
+		    (f (- n i -1) (+ f 1)))  ; (f (+ 1 (- n i)) (+ 1 f))
+		   ((> k n)
+		    (set! (cs i) val))   
+		 (set! val (* val f))))))))
+    (lambda (n)  
+      (let ((len (/ (* n 3) 2)))
+	(let ((num (make-float-vector len))
+	      (den (make-float-vector len))
+	      (b2 (bessel-i n)))
+	  (let ((p (gsl-roots (copy b2 (make-vector (length b2))))))
+	    (do ((i 0 (+ i 1)))
+		((= i n))
+	      (set! (p i) (/ (p i) (expt (b2 0) (/ 1.0 n)))))
+	    (do ((j 0 (+ j 3))
+		 (i 0 (+ i 2)))
+		((>= i n))
+	      (set! (num    j   ) 0.0)
+	      (set! (num (+ j 1)) 0.0)
+	      (set! (num (+ j 2)) 1.0)
+	      (set! (den    j   ) 1.0)
+	      (set! (den (+ j 1)) (* -2.0 (real-part (p i))))
+	      (set! (den (+ j 2)) (real-part (* (p i) (p (+ i 1)))))))
+	  (list num den))))))
 
 (define make-bessel-lowpass 
   (let ((documentation "(make-bessel-lowpass n fc) returns a lowpass Bessel filter; n = order, fc = cutoff freq (srate = 1.0): (make-bessel-lowpass 4 .1)"))
@@ -332,7 +335,8 @@ fl and fh are edge freqs (srate=1.0): (make-inverse-chebyshev-bandstop 8 .1 .4 9
       (if (odd? n) (set! n (+ n 1)))
       (let ((coeffs (let ((proto (bessel-prototype n)))
 		      (analog->digital n (car proto) (cadr proto) fc))))
-	(make-filter :xcoeffs (car coeffs) :ycoeffs (cadr coeffs))))))
+	(make-filter :xcoeffs (car coeffs) 
+		     :ycoeffs (cadr coeffs))))))
 
 (define make-bessel-highpass 
   (let ((documentation "(make-bessel-highpass n fc) returns a highpass Bessel filter; n = order, fc = cutoff freq (srate = 1.0): (make-bessel-highpass 8 .1)"))
@@ -340,7 +344,8 @@ fl and fh are edge freqs (srate=1.0): (make-inverse-chebyshev-bandstop 8 .1 .4 9
       (if (odd? n) (set! n (+ n 1)))
       (let ((coeffs (let ((hproto (prototype->highpass n (bessel-prototype n))))
 		      (analog->digital n (car hproto) (cadr hproto) fc))))
-	(make-filter :xcoeffs (car coeffs) :ycoeffs (cadr coeffs))))))
+	(make-filter :xcoeffs (car coeffs) 
+		     :ycoeffs (cadr coeffs))))))
 
 (define make-bessel-bandpass 
   (let ((documentation "(make-bessel-bandpass n fl fh) returns a bandpass Bessel filter; n = order, fl and fh are edge freqs (srate=1.0): (make-bessel-bandpass 4 .1 .2)"))
@@ -362,37 +367,31 @@ fl and fh are edge freqs (srate=1.0): (make-inverse-chebyshev-bandstop 8 .1 .4 9
 ;;; ---------------- Elliptic ---------------- 
 
 (define* (elliptic-prototype n (ripple 1.0) (loss-dB 60.0))
-  
-  (define* (minimize-function f xmin xmax arg1 arg2)
-    (let* ((n 20)
-	   (x (make-float-vector n))
-	   (fx (f xmin arg1 arg2)))
-      (do ((i 0 (+ i 1)))
-	  ((= i n))
-	(do ((step (/ (- xmax xmin) (- n 1.0)))
-	     (j 0 (+ j 1))
-	     (s xmin (+ s step)))
-	    ((= j (- n 1)))
-	  (float-vector-set! x j s))
-	(set! (x (- n 1)) xmax)
-	(do ((j 0 (+ j 1)))
-	    ((= j n))
-	  (let ((ft (f (x j) arg1 arg2)))
-	    (if (< ft fx)
-		(begin
-		  (set! fx ft)
-		  (set! xmax (x (if (< j (- n 1)) (+ j 1) (- n 1))))
-		  (set! xmin (x (if (> j 0) (- j 1) 0))))))))
-      (/ (+ xmax xmin) 2.0)))
-  
-  (define (findm m arg1 arg2)
-    (abs (- (/ (gsl-ellipk m) (gsl-ellipk (- 1.0 m))) arg1)))
-  
-  (define (findv u arg1 arg2)
-    (let ((vals (gsl-ellipj u arg1)))
-      (abs (- arg2 (/ (car vals) (cadr vals))))))
-  
-  (let ((e (sqrt (- (expt 10.0 (* 0.1 ripple)) 1.0))))
+  (let ((minimize-function 
+	 (lambda* (f xmin xmax arg1 arg2)
+	   (let* ((n 20)
+		  (x (make-float-vector n))
+		  (fx (f xmin arg1 arg2)))
+	     (do ((i 0 (+ i 1)))
+		 ((= i n))
+	       (do ((step (/ (- xmax xmin) (- n 1.0)))
+		    (j 0 (+ j 1))
+		    (s xmin (+ s step)))
+		   ((= j (- n 1)))
+		 (float-vector-set! x j s))
+	       (set! (x (- n 1)) xmax)
+	       (do ((j 0 (+ j 1)))
+		   ((= j n))
+		 (let ((ft (f (x j) arg1 arg2)))
+		   (if (< ft fx)
+		       (begin
+			 (set! fx ft)
+			 (set! xmax (x (if (< j (- n 1)) (+ j 1) (- n 1))))
+			 (set! xmin (x (if (> j 0) (- j 1) 0))))))))
+	     (/ (+ xmax xmin) 2.0))))
+	
+	(e (sqrt (- (expt 10.0 (* 0.1 ripple)) 1.0))))
+    
     (let ((k1 (/ e (sqrt (- (expt 10.0 (* 0.1 loss-dB)) 1.0))))
 	  (len (/ (* n 3) 2)))
       (let ((k1p (sqrt (- 1.0 (* k1 k1))))
@@ -404,7 +403,12 @@ fl and fh are edge freqs (srate=1.0): (make-inverse-chebyshev-bandstop 8 .1 .4 9
 	      (kr 0.0))
 	  (if (> (abs (- 1.0 (* k1p k1p))) eps)
 	      (set! kr (* n (/ (gsl-ellipk (* k1 k1)) (gsl-ellipk (* k1p k1p))))))
-	  (set! m (minimize-function findm 0.001 0.999 kr)))
+	  (set! m (minimize-function 
+		   (lambda (m arg1 arg2)
+		     (abs (- (/ (gsl-ellipk m) 
+				(gsl-ellipk (- 1.0 m)))
+			     arg1)))
+		   0.001 0.999 kr)))
 	(let ((k (gsl-ellipk m))
 	      (cv (make-float-vector (floor (* 0.5 3 (+ n 1))))))
 	  (do ((i 0 (+ i 2))
@@ -423,7 +427,11 @@ fl and fh are edge freqs (srate=1.0): (make-inverse-chebyshev-bandstop 8 .1 .4 9
 		  (set! (num    j   ) 1.0)
 		  (set! (num (+ j 1)) (* -2.0 (real-part z)))
 		  (set! (num (+ j 2)) pz)))))
-	  (let ((vals (let ((v0 (let ((minf (minimize-function findv 0.0 (/ 1.0 e) (* k1p k1p) (/ 1.0 e))))
+	  (let ((vals (let ((v0 (let ((minf (minimize-function
+					     (lambda (u arg1 arg2)
+					       (let ((vals (gsl-ellipj u arg1)))
+						 (abs (- arg2 (/ (car vals) (cadr vals))))))
+					     0.0 (/ 1.0 e) (* k1p k1p) (/ 1.0 e))))
 				  (/ (* k minf)
 				     (* n (gsl-ellipk (* k k1)))))))
 			(gsl-ellipj v0 (- 1.0 m)))))
@@ -451,7 +459,8 @@ fc = cutoff freq (srate = 1.0): (make-elliptic-lowpass 8 .25 .01 90)"))
       (if (odd? n) (set! n (+ n 1)))
       (let* ((proto (elliptic-prototype n ripple loss-dB))
 	     (coeffs (analog->digital n (car proto) (cadr proto) fc)))
-	(make-filter :xcoeffs (float-vector-scale! (car coeffs) (caddr proto)) :ycoeffs (cadr coeffs))))))
+	(make-filter :xcoeffs (float-vector-scale! (car coeffs) (caddr proto)) 
+		     :ycoeffs (cadr coeffs))))))
 
 (define make-elliptic-highpass 
   (let ((documentation "(make-elliptic-highpass n fc (ripple 1.0) (loss-dB 60.0)) returns a highpass elliptic filter; n = order, \
@@ -461,7 +470,8 @@ fc = cutoff freq (srate = 1.0): (make-elliptic-highpass 8 .25 .01 90)"))
       (let* ((proto (elliptic-prototype n ripple loss-dB))
 	     (coeffs (let ((hproto (prototype->highpass n proto)))
 		       (analog->digital n (car hproto) (cadr hproto) fc))))
-	(make-filter :xcoeffs (float-vector-scale! (car coeffs) (caddr proto)) :ycoeffs (cadr coeffs))))))
+	(make-filter :xcoeffs (float-vector-scale! (car coeffs) (caddr proto)) 
+		     :ycoeffs (cadr coeffs))))))
 
 (define make-elliptic-bandpass 
   (let ((documentation "(make-elliptic-bandpass n fl fh (ripple 1.0) (loss-dB 60.0)) returns a bandpass elliptic filter; n = order, \
