@@ -193,16 +193,6 @@
   (define (checker type)
     (find-handler type cadr))
 
-  (define* (cload->signature type rtn)
-    (case (C-type->s7-type type)
-      ((real)      (if rtn 'float? 'real?))
-      ((integer)   'integer?)
-      ((string)    'string?)
-      ((boolean)   'boolean?)
-      ((character) 'char?)
-      ((c_pointer) 'c-pointer?)
-      (else #t)))
-
   (define (signature->pl type)
     (case type
       ((integer?)   #\i)
@@ -234,42 +224,49 @@
 			     (cons 'char? 0) (cons 'string? 0) (cons 'c-pointer? 0) (cons 't 0)))
 	  (signatures (make-hash-table)))
       
-      (define (make-signature rtn args)
-	
-	(define (compress sig)
-	  (do ((sig sig (cdr sig)))
-	      ((not (and (pair? sig) 
-			 (pair? (cdr sig))
-			 (eq? (car sig) (cadr sig))))
-	       sig)))
-	
-	(let ((sig (list (cload->signature rtn #t)))
-	      (cyclic #f))
-	  (for-each
-	   (lambda (arg)
-	     (set! sig (cons (cload->signature arg) sig)))
-	   args)
-	  (let ((len (length sig)))
-	    (set! sig (compress sig))
-	    (set! cyclic (not (= len (length sig)))))
-	  (set! sig (reverse sig))
-	  (unless (signatures sig) ; it's not in our collection yet
-	    (let ((pl (make-string (+ (if cyclic 4 3) (length sig))))
-		  (loc (if cyclic 4 3)))
-	      (set! (pl 0) #\p) 
-	      (if cyclic
-		  (begin (set! (pl 1) #\c) (set! (pl 2) #\l) (set! (pl 3) #\_))
-		  (begin (set! (pl 1) #\l) (set! (pl 2) #\_)))
-	      (for-each 
-	       (lambda (typer)
-		 (set! (pl loc) (signature->pl typer))
-		 (let ((count (or (assq typer sig-symbols)
-				  (assq 't sig-symbols))))
-		   (set-cdr! count (+ (cdr count) 1)))
-		 (set! loc (+ loc 1)))
-	       sig)
-	      (set! (signatures sig) pl)))
-	  sig))
+      (define make-signature 
+	(let ((cload->signature 
+	       (lambda* (type rtn)
+		 (case (C-type->s7-type type)
+		   ((real)      (if rtn 'float? 'real?))
+		   ((integer)   'integer?)
+		   ((string)    'string?)
+		   ((boolean)   'boolean?)
+		   ((character) 'char?)
+		   ((c_pointer) 'c-pointer?)
+		   (else #t)))))
+	  (lambda (rtn args)
+	    (let ((sig (list (cload->signature rtn #t)))
+		  (cyclic #f))
+	      (for-each
+	       (lambda (arg)
+		 (set! sig (cons (cload->signature arg) sig)))
+	       args)
+	      (let ((len (length sig)))
+		(set! sig (do ((sig sig (cdr sig)))
+			      ((not (and (pair? sig) 
+					 (pair? (cdr sig))
+					 (eq? (car sig) (cadr sig))))
+			       sig)))
+		(set! cyclic (not (= len (length sig)))))
+	      (set! sig (reverse sig))
+	      (unless (signatures sig) ; it's not in our collection yet
+		(let ((pl (make-string (+ (if cyclic 4 3) (length sig))))
+		      (loc (if cyclic 4 3)))
+		  (set! (pl 0) #\p) 
+		  (if cyclic
+		      (begin (set! (pl 1) #\c) (set! (pl 2) #\l) (set! (pl 3) #\_))
+		      (begin (set! (pl 1) #\l) (set! (pl 2) #\_)))
+		  (for-each 
+		   (lambda (typer)
+		     (set! (pl loc) (signature->pl typer))
+		     (let ((count (or (assq typer sig-symbols)
+				      (assq 't sig-symbols))))
+		       (set-cdr! count (+ (cdr count) 1)))
+		     (set! loc (+ loc 1)))
+		   sig)
+		  (set! (signatures sig) pl)))
+	      sig))))
       
       (define (initialize-c-file)
 	;; C header stuff
@@ -573,47 +570,48 @@
 	       (system (format #f "gcc ~A -shared -o ~A ~A ~A" 
 			       o-file-name so-file-name *cload-ldflags* ldflags)))))
       
-      (define (handle-declaration func)
-	
-	(define (add-one-constant type name)
-	  ;; C constant -> scheme
-	  (let ((c-type (if (pair? type) (cadr type) type)))
-	    (if (symbol? name)
-		(set! constants (cons (list c-type (symbol->string (collides? name))) constants))
-		(for-each 
-		 (lambda (c)
-		   (set! constants (cons (list c-type (symbol->string (collides? c))) constants)))
-		 name))))
-	
-	(define (add-one-macro type name)
-	  ;; C macro (with definition check) -> scheme
-	  (let ((c-type (if (pair? type) (cadr type) type)))
-	    (if (symbol? name)
-		(set! macros (cons (list c-type (symbol->string (collides? name))) macros))
-		(for-each 
-		 (lambda (c)
-		   (set! macros (cons (list c-type (symbol->string (collides? c))) macros)))
-		 name))))
-	
-	(define (check-doc func-data)
-	  (let ((doc (caddr func-data)))
-	    (if (and (string? doc)
-		     (> (length doc) 0))
-		func-data
-		(append (list (car func-data) (cadr func-data) (car func-data)) (cdddr func-data)))))
-	
-	;; functions
-	(if (>= (length func) 3)
-	    (apply add-one-function func)
-	    (case (car func)
-	      ((in-C)       (format p "~A~%" (cadr func)))
-	      ((C-init)     (set! inits (cons (cadr func) inits)))
-	      ((C-macro)    (apply add-one-macro (cadr func)))
-	      ((C-function) (collides? (caadr func)) (set! functions (cons (check-doc (cadr func)) functions)))
-	      (else         (apply add-one-constant func)))))
+      (define handle-declaration 
+	(let ()
+	  (define (add-one-constant type name)
+	    ;; C constant -> scheme
+	    (let ((c-type (if (pair? type) (cadr type) type)))
+	      (if (symbol? name)
+		  (set! constants (cons (list c-type (symbol->string (collides? name))) constants))
+		  (for-each 
+		   (lambda (c)
+		     (set! constants (cons (list c-type (symbol->string (collides? c))) constants)))
+		   name))))
+	  
+	  (define (add-one-macro type name)
+	    ;; C macro (with definition check) -> scheme
+	    (let ((c-type (if (pair? type) (cadr type) type)))
+	      (if (symbol? name)
+		  (set! macros (cons (list c-type (symbol->string (collides? name))) macros))
+		  (for-each 
+		   (lambda (c)
+		     (set! macros (cons (list c-type (symbol->string (collides? c))) macros)))
+		   name))))
+	  
+	  (define (check-doc func-data)
+	    (let ((doc (caddr func-data)))
+	      (if (and (string? doc)
+		       (> (length doc) 0))
+		  func-data
+		  (append (list (car func-data) (cadr func-data) (car func-data)) (cdddr func-data)))))
+	  
+	  (lambda (func)
+	    ;; functions
+	    (if (>= (length func) 3)
+		(apply add-one-function func)
+		(case (car func)
+		  ((in-C)       (format p "~A~%" (cadr func)))
+		  ((C-init)     (set! inits (cons (cadr func) inits)))
+		  ((C-macro)    (apply add-one-macro (cadr func)))
+		  ((C-function) (collides? (caadr func)) (set! functions (cons (check-doc (cadr func)) functions)))
+		  (else         (apply add-one-constant func)))))))
       
       
-      ;; this is the body of c-define
+      ;; c-define-1 (called in c-define macro above)
       (unless (and output-name
 		   (file-exists? c-file-name)
 		   (file-exists? so-file-name)
@@ -639,11 +637,6 @@
 	(load so-file-name new-env)))))
 
 
-
-;;; backwards compatibility
-(define define-c-function c-define)
-
-
 #|
 (let ((cd (symbol "complex double"))
       (cd* (symbol "complex double *")))
