@@ -72,15 +72,15 @@
 				   (sounds))
 				  #f))))
 	(if (pair? mark-setting)
-	    (let* ((snd (car mark-setting))
-		   (chn (cadr mark-setting))
-		   (max-edits (apply + (edits snd chn)))
-		   (descr ())
-		   (header (list id sound: snd (short-file-name snd) channel: chn)))
-	      (do ((i max-edits (- i 1)))
-		  ((< i 0))
-		(set! descr (cons (and (member id (marks snd chn i)) (mark-sample id i)) descr)))
-	      (cons header descr))
+	    (let ((snd (car mark-setting))
+		  (chn (cadr mark-setting)))
+	      (let ((max-edits (apply + (edits snd chn)))
+		    (descr ())
+		    (header (list id sound: snd (short-file-name snd) channel: chn)))
+		(do ((i max-edits (- i 1)))
+		    ((< i 0))
+		  (set! descr (cons (and (member id (marks snd chn i)) (mark-sample id i)) descr)))
+		(cons header descr)))
 	    (error 'no-such-mark (list "describe-mark" id)))))))
 
 
@@ -101,15 +101,13 @@
     (lambda ids
       (let* ((samps (map mark-sample ids))
 	     (max-samp (apply max samps)))
-	(let pad-to-sync ((lst-ids ids)
-			  (lst-samps samps))
-	  (if (pair? lst-ids)
-	      (begin
-		(if (< (car lst-samps) max-samp)
-		    (let ((nsamps (- max-samp (car lst-samps)))
-			  (snd-chn (mark-home (car lst-ids))))
-		      (insert-samples 0 nsamps (make-float-vector nsamps) (car snd-chn) (cadr snd-chn))))
-		(pad-to-sync (cdr lst-ids) (cdr lst-samps)))))))))
+	(do ((lst-ids ids (cdr lst-ids))
+	     (lst-samps samps (cdr lst-samps)))
+	    ((not (pair? lst-ids)))
+	  (if (< (car lst-samps) max-samp)
+	      (let ((nsamps (- max-samp (car lst-samps)))
+		    (snd-chn (mark-home (car lst-ids))))
+		(insert-samples 0 nsamps (make-float-vector nsamps) (car snd-chn) (cadr snd-chn)))))))))
 
 
 ;;; -------- fit selection between marks, expanding via granulate (this needs some tweaking...)
@@ -127,32 +125,32 @@
 	    (snd-print (format #f "~A is in ~A[~A] but ~A is in ~A[~A]?" 
 			       m1 (car m1-home) (cadr m1-home)
 			       m2 (car m2-home) (cadr m2-home)))
-	    (let* ((mark-samps (- m2-samp m1-samp))
-		   (selection-samps (selection-framples))
-		   (reg-data (let ((data (make-float-vector selection-samps))
-				   (rd (make-sampler (selection-position))))
-			       (do ((i 0 (+ 1 i)))
-				   ((= i selection-samps))
-				 (set! (data i) (rd)))
-			       data))
-		   (inctr 0))
-	      (if (= mark-samps selection-samps)
-		  (map-channel (lambda (y) 
-				 (let ((val (+ y (reg-data inctr))))
-				   (set! inctr (+ 1 inctr))
-				   val))
-			       m1-samp mark-samps (car m1-home) (cadr m1-home))
-		  (let ((gr (make-granulate :expansion (/ mark-samps selection-samps)
-					    :input (lambda (dir)
-						     (if (or (>= inctr selection-samps)
-							     (< inctr 0))
-							 0.0
-							 (let ((val (reg-data inctr)))
-							   (set! inctr (+ inctr dir))
-							   val))))))
-		    (map-channel (lambda (y)
-				   (+ y (granulate gr)))
-				 m1-samp mark-samps (car m1-home) (cadr m1-home))))))))))
+	    (let ((selection-samps (selection-framples)))
+	      (let ((mark-samps (- m2-samp m1-samp))
+		    (reg-data (let ((data (make-float-vector selection-samps))
+				    (rd (make-sampler (selection-position))))
+				(do ((i 0 (+ 1 i)))
+				    ((= i selection-samps))
+				  (set! (data i) (rd)))
+				data))
+		    (inctr 0))
+		(if (= mark-samps selection-samps)
+		    (map-channel (lambda (y) 
+				   (let ((val (+ y (reg-data inctr))))
+				     (set! inctr (+ 1 inctr))
+				     val))
+				 m1-samp mark-samps (car m1-home) (cadr m1-home))
+		    (let ((gr (make-granulate :expansion (/ mark-samps selection-samps)
+					      :input (lambda (dir)
+						       (if (or (>= inctr selection-samps)
+							       (< inctr 0))
+							   0.0
+							   (let ((val (reg-data inctr)))
+							     (set! inctr (+ inctr dir))
+							     val))))))
+		      (map-channel (lambda (y)
+				     (+ y (granulate gr)))
+				   m1-samp mark-samps (car m1-home) (cadr m1-home)))))))))))
 
 
 ;;; -------- pad-marks inserts silence before each in a list of marks
@@ -219,14 +217,14 @@
 				    (find-another-mark (cdr ms)))))))))
 	(if (and (mark? m1)
 		 (mark? m2))
-	    (let* ((pos1 (mark-sample m1))
-		   (pos2 (mark-sample m2))
-		   (beg (min pos1 pos2))
-		   (end (max pos1 pos2)))
-	      (play (car (mark-home m1)) 
-		    :channel (cadr (mark-home m1))
-		    :start beg 
-		    :end end)))))))
+	    (let ((pos1 (mark-sample m1))
+		  (pos2 (mark-sample m2)))
+	      (let ((beg (min pos1 pos2))
+		    (end (max pos1 pos2)))
+		(play (car (mark-home m1)) 
+		      :channel (cadr (mark-home m1))
+		      :start beg 
+		      :end end))))))))
 
 
 ;;; -------- report-mark-names causes mark names to be posted in the minibuffer as a sound is played
@@ -236,18 +234,18 @@
     (lambda ()
       (hook-push start-playing-hook 
 		 (lambda (snd)
-		   (let* ((marklist (marks snd 0))
-			  (report-mark-names-play-hook
-			   (let ((samplist (map mark-sample marklist))
-				 (samp 0))
-			     (lambda (hook)
-			       (set! samp (+ samp (hook 'size)))
-			       (if (and (pair? samplist)
-					(>= samp (car samplist)))
-				   (begin
-				     (status-report (mark-name (car marklist)) snd)
-				     (set! marklist (cdr marklist))
-				     (set! samplist (cdr samplist))))))))
+		   (let ((report-mark-names-play-hook
+			   (let ((marklist (marks snd 0)))
+			     (let ((samplist (map mark-sample marklist))
+				   (samp 0))
+			       (lambda (hook)
+				 (set! samp (+ samp (hook 'size)))
+				 (if (and (pair? samplist)
+					  (>= samp (car samplist)))
+				     (begin
+				       (status-report (mark-name (car marklist)) snd)
+				       (set! marklist (cdr marklist))
+				       (set! samplist (cdr samplist)))))))))
 		     (letrec ((report-mark-names-stop-playing-hook 
 			       (lambda (hook)
 				 (status-report "" (hook 'snd))
@@ -263,7 +261,7 @@
 (define snap-marks
   (let ((documentation "snap-marks places marks at current selection boundaries"))
     (lambda ()
-      (let ((ms (list)))
+      (let ((ms ()))
 	(if (selection?)
 	    (for-each 
 	     (lambda (select)
@@ -311,13 +309,13 @@
 			   (let* ((samp (mark-sample mrk))
 				  (bps (/ (beats-per-minute snd chn) 60.0))
 				  (sr (srate snd))
-				  (beat (floor (/ (* samp bps) sr)))
-				  (lower (floor (/ (* beat sr) bps)))
-				  (higher (floor (/ (* (+ 1 beat) sr) bps))))
-			     (set! (mark-sample mrk)
-				   (if (< (- samp lower) (- higher samp))
-				       lower
-				       higher)))))))))))
+				  (beat (floor (/ (* samp bps) sr))))
+			     (let ((lower (floor (/ (* beat sr) bps)))
+				   (higher (floor (/ (* (+ 1 beat) sr) bps))))
+			       (set! (mark-sample mrk)
+				     (if (< (- samp lower) (- higher samp))
+					 lower
+					 higher))))))))))))
 
 ;;; -------- mark-explode
 ;;;
