@@ -313,23 +313,22 @@ the desired phase.
 	     (snd-msg "Please leave default or enter [1] [2] [4] [9] [12] [13]~%")
 	     (set! numf 1)))
 	  
-	  (let ((run-state (case numf
-			     ((1) state-0)
-			     ((2) state-5)
-			     ((4) state-4)
-			     ((9) state-2)
-			     ((12) state-1)
-			     ((13) state-3))))
-	    
-	    (do ((i beg (+ 1 i)))
-		((= i end))
-	      (let ((outvalA (* att (readin rdA)))
-		    (add-fl 0.0))
-		(do ((j 0 (+ 1 j)))
-		    ((= j numf))
-		  (set-coeffs formfil (array-ref run-state j 0) (array-ref run-state j 1) (array-ref run-state j 2))
-		  (set! add-fl (+ add-fl (mvmfilt formfil outvalA))))
-		(locsig loc i (* (env ampf) add-fl))))))))))
+	  (do ((run-state (case numf
+			    ((1) state-0)
+			    ((2) state-5)
+			    ((4) state-4)
+			    ((9) state-2)
+			    ((12) state-1)
+			    ((13) state-3)))
+	       (i beg (+ 1 i)))
+	      ((= i end))
+	    (let ((outvalA (* att (readin rdA)))
+		  (add-fl 0.0))
+	      (do ((j 0 (+ 1 j)))
+		  ((= j numf))
+		(set-coeffs formfil (array-ref run-state j 0) (array-ref run-state j 1) (array-ref run-state j 2))
+		(set! add-fl (+ add-fl (mvmfilt formfil outvalA))))
+	      (locsig loc i (* (env ampf) add-fl)))))))))
     
 ;; (let* ((ifile "dog.snd")
 ;;        (ofile "gmax_dog.snd")
