@@ -86,11 +86,11 @@
 ;;; -------- play sound until c-g
 
 (define play-until-c-g
-  (let ((documentation "(play-until-c-g) plays the selected sound until you interrupt it via C-g"))
+  (let ((documentation "(play-until-c-g) plays the selected sound until you interrupt it via C-g")
+	(play-once (lambda (reason)
+		     (if (= reason 0)
+			 (play (selected-sound) :start 0 :stop play-once)))))
     (lambda ()
-      (define (play-once reason)
-	(if (= reason 0)
-	    (play (selected-sound) :start 0 :stop play-once)))
       (play (selected-sound) :start 0 :stop play-once))))
 
 
@@ -160,13 +160,14 @@ x typed in the graph, or C-g in the listener exits the loop."))
   (let ((documentation "(play-with-amps snd :rest amps) plays snd with each channel scaled by the corresponding 
 amp: (play-with-amps 0 1.0 0.5) plays channel 2 of stereo sound at half amplitude"))
     (lambda (sound . amps)
-      (let ((chans (channels sound)))
-	(do ((chan 0 (+ 1 chan)))
-	    ((= chan chans))
-	  (let ((player (make-player sound chan)))
-	    (set! (amp-control player) (amps chan))
-	    (add-player player)))
-	(start-playing chans (srate sound))))))
+      (do ((chans (channels sound))
+	   (chan 0 (+ 1 chan)))
+	  ((= chan chans)
+	   (start-playing chans (srate sound)))
+	(let ((player (make-player sound chan)))
+	  (set! (amp-control player) (amps chan))
+	  (add-player player))))))
+      
 
 ;;; play-sine and play-sines
 
