@@ -45,7 +45,6 @@
 	  (apply #_make-hash-table args))))
 
 (define bytevector byte-vector)
-;(define ->bytevector string->byte-vector)
 (define bytevector? byte-vector?)
 (define make-bytevector make-byte-vector)
 (define bytevector-ref string-ref)
@@ -208,7 +207,7 @@
       (if (not (null? (cdr args)))
 	  (for-each
 	   (lambda (arg expr)
-	     (set! form `((lambda ,arg ,form) ,expr)))
+	     (set! form (list (list 'lambda arg form) expr)))
 	   (cdr args)
 	   (cdr exprs)))
       form)))
@@ -342,7 +341,7 @@
 (define-macro (delay-force expr) 
   `(make-promise #f (lambda () ,expr)))
 (define-macro (r7rs-delay expr) ; "delay" is taken damn it
-  `(delay-force (make-promise #t (lambda () ,expr))))
+  (list 'delay-force (list 'make-promise #t (list 'lambda () expr))))
 (define (make-promise done? proc) 
   (list (cons done? proc)))
 (define (force promise)
