@@ -730,17 +730,17 @@ widgets (list (0)main-app (1)main-shell (2)main-pane (3)sound-pane (4)listener-p
   int loc;
 #if USE_MOTIF
   bad_temp = Xen_list_2(C_string_to_Xen_symbol("XtAppContext"), 
-			C_ulong_to_Xen_ulong((unsigned long)MAIN_APP(ss)));
+			C_ulong_to_Xen_ulong((unsigned long)main_app(ss)));
 #else
-  bad_temp = Xen_wrap_window(MAIN_WINDOW(ss));
+  bad_temp = Xen_wrap_window(main_window(ss));
 #endif
   loc = snd_protect(bad_temp);
   res = Xen_cons(bad_temp,
-	   Xen_cons(Xen_wrap_widget(MAIN_SHELL(ss)),
-             Xen_cons(Xen_wrap_widget(MAIN_PANE(ss)),
-               Xen_cons(Xen_wrap_widget(SOUND_PANE(ss)),
+	   Xen_cons(Xen_wrap_widget(main_shell(ss)),
+             Xen_cons(Xen_wrap_widget(main_pane(ss)),
+               Xen_cons(Xen_wrap_widget(sound_pane(ss)),
 		 Xen_cons(Xen_wrap_widget(ss->listener_pane),
-		   Xen_cons(Xen_wrap_widget(SOUND_PANE_BOX(ss)),
+		   Xen_cons(Xen_wrap_widget(sound_pane_box(ss)),
 		     Xen_empty_list))))));
   snd_unprotect_at(loc);
   return(res);
@@ -785,7 +785,7 @@ static Xen g_dialog_widgets(void)
 
 void set_dialog_widget(snd_dialog_t which, widget_t wid)
 {
-  if (ss->dialogs == NULL)
+  if (!ss->dialogs)
     {
       ss->dialogs_size = 8;
       ss->num_dialogs = 0;
@@ -1312,7 +1312,7 @@ void set_highlight_color(color_t color)
   s7_symbol_set_value(s7, ss->highlight_color_symbol, Xen_wrap_pixel(color));
 #endif
 #if USE_MOTIF
-  map_over_children_with_color(MAIN_SHELL(ss), highlight_recolor_everything, old_color);
+  map_over_children_with_color(main_shell(ss), highlight_recolor_everything, old_color);
 #endif
 }
 
@@ -1784,7 +1784,7 @@ static Xen g_color_to_list(Xen obj)
 
   Xen_check_type(Xen_is_pixel(obj), obj, 1, S_color_to_list, "a color"); 
 
-  dpy = XtDisplay(MAIN_SHELL(ss));
+  dpy = XtDisplay(main_shell(ss));
   cmap = DefaultColormap(dpy, DefaultScreen(dpy));
   tmp_color.flags = DoRed | DoGreen | DoBlue;
   tmp_color.pixel = Xen_unwrap_pixel(obj);
@@ -1812,7 +1812,7 @@ static Xen g_make_color(Xen r, Xen g, Xen b, Xen alpha)
   rf = check_color_range(S_make_color, r);
   gf = check_color_range(S_make_color, g);
   bf = check_color_range(S_make_color, b);
-  dpy = XtDisplay(MAIN_SHELL(ss));
+  dpy = XtDisplay(main_shell(ss));
   cmap = DefaultColormap(dpy, DefaultScreen(dpy));
   tmp_color.flags = DoRed | DoGreen | DoBlue;
   tmp_color.red = float_to_rgb(rf);
@@ -1840,10 +1840,10 @@ void set_basic_color(color_t color)
 #endif
   ss->basic_color = color; 
 #if USE_MOTIF
-  map_over_children_with_color(MAIN_SHELL(ss), recolor_everything, old_color);
+  map_over_children_with_color(main_shell(ss), recolor_everything, old_color);
 #endif
 #if USE_GTK
-  recolor_everything(MAIN_SHELL(ss), color);
+  recolor_everything(main_shell(ss), color);
 #endif
 
 #if USE_MOTIF
@@ -2033,7 +2033,7 @@ Xen_wrap_3_args(g_set_combined_data_color_w, g_set_combined_data_color)
 void g_init_draw(void)
 {
 #if HAVE_SCHEME
-  s7_pointer i, b, p, t, r, mx, s, v, pcl_p, pcl_t;
+  s7_pointer i, b, p, t, r, mx, s, v, pcl_p, pcl_t, bi;
   i = s7_make_symbol(s7, "integer?");
   b = s7_make_symbol(s7, "boolean?");
   p = s7_make_symbol(s7, "pair?");
@@ -2044,6 +2044,7 @@ void g_init_draw(void)
   t = s7_t(s7);
   pcl_p = s7_make_circular_signature(s7, 0, 1, p);
   pcl_t = s7_make_circular_signature(s7, 0, 1, t);
+  bi = s7_make_signature(s7, 2, i, b);
 #endif
 
   dialog_widgets = Xen_undefined;
@@ -2061,7 +2062,7 @@ void g_init_draw(void)
   Xen_define_typed_procedure(S_fill_rectangle,   g_fill_rectangle_w,  4, 5, 0, H_fill_rectangle,  s7_make_signature(s7, 10, b, i, i, i, i, t, t, i, b, p));
   Xen_define_typed_procedure(S_fill_polygon,     g_fill_polygon_w,    1, 4, 0, H_fill_polygon,    s7_make_signature(s7, 6, v, v, t, t, i, p));
   Xen_define_typed_procedure(S_make_graph_data,  g_make_graph_data_w, 0, 5, 0, H_make_graph_data, s7_make_signature(s7, 6, t, t, t, t, i, i));
-  Xen_define_typed_procedure(S_graph_data,       g_graph_data_w,      1, 7, 0, H_graph_data,      s7_make_signature(s7, 9, t, t, t, t, t, i, i, i, p));
+  Xen_define_typed_procedure(S_graph_data,       g_graph_data_w,      1, 7, 0, H_graph_data,      s7_make_signature(s7, 9, t, t, t, t, t, bi, bi, bi, p));
 
   Xen_define_typed_procedure(S_main_widgets,     g_main_widgets_w,    0, 0, 0, H_main_widgets,   pcl_p);
   Xen_define_typed_procedure(S_dialog_widgets,   g_dialog_widgets_w,  0, 0, 0, H_dialog_widgets, pcl_p);
