@@ -152,7 +152,7 @@ void erase_rectangle(chan_info *cp, graphics_context *ax, int x0, int y0, int wi
 
 void draw_string(graphics_context *ax, int x0, int y0, const char *str, int len)
 {
-  if (ax->current_font == NULL) return;
+  if (!ax->current_font) return;
   if ((!str) || (!(*str))) return;
   if (!(g_utf8_validate(str, -1, NULL)))
     return;
@@ -906,7 +906,7 @@ GtkWidget *make_color_orientation_dialog(bool managed)
 
       ccd_dialog = snd_gtk_dialog_new();
 #if GTK_CHECK_VERSION(3, 14, 0)
-      gtk_window_set_transient_for(GTK_WINDOW(ccd_dialog), GTK_WINDOW(MAIN_SHELL(ss)));
+      gtk_window_set_transient_for(GTK_WINDOW(ccd_dialog), GTK_WINDOW(main_shell(ss)));
 #endif
       SG_SIGNAL_CONNECT(ccd_dialog, "delete_event", delete_color_orientation_dialog, NULL);
       gtk_window_set_title(GTK_WINDOW(ccd_dialog), "Color");
