@@ -49,10 +49,10 @@ static void graph_redisplay(void)
   graphics_context *ax;
 
   if (!(transform_dialog_is_active())) return;
-  if (graph_drawer == NULL) return;
+  if (!graph_drawer) return;
 
   wn = WIDGET_TO_WINDOW(graph_drawer);
-  if (wn == NULL) return;
+  if (!wn) return;
 
   if (!axis_ap)
     {
@@ -880,7 +880,7 @@ GtkWidget *make_transform_dialog(bool managed)
 
       transform_dialog = snd_gtk_dialog_new();
 #if GTK_CHECK_VERSION(3, 14, 0)
-      gtk_window_set_transient_for(GTK_WINDOW(transform_dialog), GTK_WINDOW(MAIN_SHELL(ss)));
+      gtk_window_set_transient_for(GTK_WINDOW(transform_dialog), GTK_WINDOW(main_shell(ss)));
 #endif
       gtk_widget_set_name(transform_dialog, "fft_dialog");
       SG_SIGNAL_CONNECT(transform_dialog, "delete_event", delete_transform_dialog, NULL);
