@@ -157,7 +157,7 @@ static const char *checker(glistener *g, const char *text)
   bool err = false;
   result = s7_f(s7);
 
-  if (s7_begin_hook(s7) != NULL) return(NULL); 
+  if (s7_begin_hook(s7)) return(NULL); 
   err_port = s7_set_current_error_port(s7, s7_open_output_string(s7));
   err_loc = s7_gc_protect(s7, err_port);
   port = s7_open_input_string(s7, text);
@@ -360,11 +360,11 @@ static s7_pointer g_set_top_level_let(s7_scheme *sc, s7_pointer args)
 
 static void evaluator(glistener *g, const char *text)
 {
-  int gc_loc;
+  unsigned int gc_loc;
   s7_pointer old_port, result;
   char *errmsg = NULL;
   
-  if (s7_begin_hook(s7) != NULL) return;      /* s7 is already running (user typed <cr> during computation) */
+  if (s7_begin_hook(s7)) return;      /* s7 is already running (user typed <cr> during computation) */
   
   old_port = s7_set_current_error_port(s7, s7_open_output_string(s7));
   gc_loc = s7_gc_protect(s7, old_port);
@@ -610,8 +610,8 @@ static void make_listener_widget(int height)
       gtk_widget_show(frame);
 
       if (sound_style(ss) != SOUNDS_IN_SEPARATE_WINDOWS)
-	gtk_paned_pack2(GTK_PANED(SOUND_PANE(ss)), frame, false, true); /* add2 but resize=false */
-      else gtk_container_add(GTK_CONTAINER(MAIN_PANE(ss)), frame);
+	gtk_paned_pack2(GTK_PANED(sound_pane(ss)), frame, false, true); /* add2 but resize=false */
+      else gtk_container_add(GTK_CONTAINER(main_pane(ss)), frame);
 
       ss->listener = glistener_new(frame, listener_init);
       glistener_set_evaluator(ss->listener, evaluator);
@@ -682,15 +682,15 @@ void handle_listener(bool open)
       gtk_widget_hide(view_listener_menu);
     }
 
-  if ((SOUND_PANE(ss)) && /* might be run -separate with no sound open */
+  if ((sound_pane(ss)) && /* might be run -separate with no sound open */
       (sound_style(ss) != SOUNDS_IN_SEPARATE_WINDOWS))
     {
       int hgt;
-      hgt = widget_height(SOUND_PANE(ss));
+      hgt = widget_height(sound_pane(ss));
       if (hgt > 100) /* we can get here before the sound window has opened, but with one pending.
 		      *   the position is in terms of current size, which is useless in this case.
 		      */
-	gtk_paned_set_position(GTK_PANED(SOUND_PANE(ss)), (gint)(hgt * .75));
+	gtk_paned_set_position(GTK_PANED(sound_pane(ss)), (gint)(hgt * .75));
     }
 }
 
@@ -828,7 +828,7 @@ leaves the lisp listener pane"
   mouse_enter_listener_hook = Xen_define_hook(S_mouse_enter_listener_hook, "(make-hook 'widget)", 1, H_mouse_enter_listener_hook);
   mouse_leave_listener_hook = Xen_define_hook(S_mouse_leave_listener_hook, "(make-hook 'widget)", 1, H_mouse_leave_listener_hook);
 
-  Xen_define_typed_procedure(S_listener_selection, g_listener_selection_w,       0, 0, 0, H_listener_selection,    s7_make_signature(s7, 1, s));
+  Xen_define_typed_procedure(S_listener_selection, g_listener_selection_w,       0, 0, 0, H_listener_selection,    s7_make_signature(s7, 1, s7_make_signature(s7, 2, s, b)));
   Xen_define_typed_procedure(S_reset_listener_cursor, g_reset_listener_cursor_w, 0, 0, 0, H_reset_listener_cursor, s7_make_signature(s7, 1, b));
   Xen_define_typed_procedure(S_goto_listener_end, g_goto_listener_end_w,         0, 0, 0, H_goto_listener_end,     s7_make_signature(s7, 1, b));
 
