@@ -48,17 +48,17 @@ static void file_print_callback(GtkWidget *w, gpointer info)
   GError *error = NULL;
 
   operation = gtk_print_operation_new ();
-  if (settings != NULL) 
+  if (settings) 
     gtk_print_operation_set_print_settings(operation, settings);
 
   g_signal_connect(G_OBJECT(operation), "begin-print", G_CALLBACK(begin_print), NULL);
   g_signal_connect(G_OBJECT(operation), "draw-page", G_CALLBACK(draw_page), NULL);
   g_signal_connect(G_OBJECT(operation), "end-print", G_CALLBACK(end_print), NULL);
 
-  res = gtk_print_operation_run(operation, GTK_PRINT_OPERATION_ACTION_PRINT_DIALOG, GTK_WINDOW(MAIN_SHELL(ss)), &error);
+  res = gtk_print_operation_run(operation, GTK_PRINT_OPERATION_ACTION_PRINT_DIALOG, GTK_WINDOW(main_shell(ss)), &error);
   if (res == GTK_PRINT_OPERATION_RESULT_APPLY)
     {
-      if (settings != NULL)
+      if (settings)
         g_object_unref(settings);
       settings = (GtkPrintSettings *)g_object_ref(gtk_print_operation_get_print_settings(operation));
     }
@@ -143,7 +143,7 @@ static void file_open_recent_callback(GtkWidget *w, gpointer info)
 
       for (i = 0; i < size; i++)
 	{
-	  if (recent_file_items[i] == NULL)
+	  if (!recent_file_items[i])
 	    {
 	      recent_file_items[i] = gtk_menu_item_new_with_label(recent_file_names[i]);
 	      gtk_menu_shell_append(GTK_MENU_SHELL(file_open_recent_cascade_menu), recent_file_items[i]);
@@ -371,7 +371,7 @@ static void menu_drag_watcher(GtkWidget *w, const char *str, int x, int y, drag_
 	{
 	  char *new_title;
 	  new_title = mus_format("%s: drop to open file", ss->startup_title);
-	  gtk_window_set_title(GTK_WINDOW(MAIN_SHELL(ss)), new_title);
+	  gtk_window_set_title(GTK_WINDOW(main_shell(ss)), new_title);
 	  have_drag_title = true;
 	  free(new_title);
 	}
@@ -440,7 +440,7 @@ GtkWidget *add_menu(void)
    */
   GtkAccelGroup *accel_group;
   accel_group = gtk_accel_group_new();
-  gtk_window_add_accel_group(GTK_WINDOW(MAIN_SHELL(ss)), accel_group);
+  gtk_window_add_accel_group(GTK_WINDOW(main_shell(ss)), accel_group);
 #endif
 
   ss->mw = (GtkWidget **)calloc(NUM_MENU_WIDGETS, sizeof(GtkWidget *));
@@ -448,7 +448,7 @@ GtkWidget *add_menu(void)
   main_menu = gtk_menu_bar_new();
   ml[m_menu] = NULL;
   add_drag_and_drop(main_menu, menu_drop_watcher, menu_drag_watcher, NULL);
-  gtk_box_pack_start(GTK_BOX(MAIN_PANE(ss)), main_menu, false, true, 0);
+  gtk_box_pack_start(GTK_BOX(main_pane(ss)), main_menu, false, true, 0);
   add_menu_style(main_menu);
   gtk_widget_show(main_menu);
 
@@ -973,7 +973,11 @@ void post_basic_popup_menu(void *e)
   if ((!sp) || (sp->nchans == 1))
     gtk_widget_hide(popup_play);
   else gtk_widget_show(popup_play);
+#if GTK_CHECK_VERSION(3, 22, 0)
+  gtk_menu_popup_at_pointer(GTK_MENU(basic_popup_menu), (const GdkEvent *)ev);
+#else
   gtk_menu_popup(GTK_MENU(basic_popup_menu), NULL, NULL, NULL, NULL, POPUP_BUTTON, EVENT_TIME(ev));
+#endif
 }
 
 
@@ -1140,7 +1144,11 @@ void post_selection_popup_menu(void *e)
       add_menu_item(selection_popup_menu, "Info",           NULL, (GCallback)popup_selection_info_callback);
     }
 
+#if GTK_CHECK_VERSION(3, 22, 0)
+  gtk_menu_popup_at_pointer(GTK_MENU(selection_popup_menu), (const GdkEvent *)ev);
+#else
   gtk_menu_popup(GTK_MENU(selection_popup_menu), NULL, NULL, NULL, NULL, POPUP_BUTTON, EVENT_TIME(ev));
+#endif
 }
 
 
@@ -1322,7 +1330,11 @@ void post_fft_popup_menu(void *e)
       add_menu_item(fft_popup_menu, "Peaks->fft.txt", NULL, (GCallback)popup_peaks_callback);
     }
 
+#if GTK_CHECK_VERSION(3, 22, 0)
+  gtk_menu_popup_at_pointer(GTK_MENU(fft_popup_menu), (const GdkEvent *)ev);
+#else
   gtk_menu_popup(GTK_MENU(fft_popup_menu), NULL, NULL, NULL, NULL, POPUP_BUTTON, EVENT_TIME(ev));
+#endif
 }
 
 
@@ -1861,8 +1873,8 @@ void show_toolbar(void)
       add_toolbar_style(toolbar);
       gtk_toolbar_set_icon_size(GTK_TOOLBAR(toolbar), GTK_ICON_SIZE_SMALL_TOOLBAR);
 #endif
-      gtk_box_pack_start(GTK_BOX(MAIN_PANE(ss)), toolbar, false, false, 0); /* MAIN_PANE = top level vbox */
-      gtk_box_reorder_child(GTK_BOX(MAIN_PANE(ss)), toolbar, 1);            /* put toolbar just under the top level menubar */
+      gtk_box_pack_start(GTK_BOX(main_pane(ss)), toolbar, false, false, 0); /* main_pane = top level vbox */
+      gtk_box_reorder_child(GTK_BOX(main_pane(ss)), toolbar, 1);            /* put toolbar just under the top level menubar */
 
 
       add_to_toolbar(toolbar, ICON_NEW,                 "open a new sound",           (GCallback)file_new_callback);
