@@ -521,7 +521,7 @@ static void sync_button_click(GtkWidget *w, gpointer data)
       chan_info *cp;
       if (sp->sync > ss->sound_sync_max) ss->sound_sync_max = sp->sync;
       cp = sp->lacp;
-      if (cp == NULL) cp = any_selected_channel(sp);
+      if (!cp) cp = any_selected_channel(sp);
       goto_graph(cp);
       if (cp->cursor_on) sync_cursors(cp, cursor_sample(cp));
       apply_x_axis_change(cp);
@@ -1133,7 +1133,7 @@ void display_filter_env(snd_info *sp)
   if (height < MIN_FILTER_GRAPH_HEIGHT) return;
   width = widget_width(drawer);
 
-  if (sp->filter_ax == NULL)
+  if (!sp->filter_ax)
     {
       ax = (graphics_context *)calloc(1, sizeof(graphics_context));
       ax->wn = WIDGET_TO_WINDOW(drawer);
@@ -1156,7 +1156,7 @@ void display_filter_env(snd_info *sp)
 
   edp->in_dB = sp->filter_control_in_dB;
   edp->with_dots = true;
-  if (sp->filter_control_envelope == NULL) 
+  if (!sp->filter_control_envelope) 
     sp->filter_control_envelope = default_env(sp->filter_control_xmax, 1.0);
 
   
@@ -1510,13 +1510,17 @@ snd_info *add_sound_window(char *filename, read_only_t read_only, file_info *hdr
   nchans = hdr->chans;
   if (nchans <= 0) nchans = 1;
 
-  app_y = widget_y(MAIN_SHELL(ss));
-  app_dy = widget_height(MAIN_SHELL(ss));
+  app_y = widget_y(main_shell(ss));
+  app_dy = widget_height(main_shell(ss));
 
   if (auto_resize(ss))
     {
       int screen_y;
+#if GTK_CHECK_VERSION(3, 22, 0)
+      screen_y = 600; /* who knows? */
+#else
       screen_y = gdk_screen_height();
+#endif
       app_dy = (screen_y - app_y - app_dy - 20 * nchans);
     }
   else app_dy -= listener_height();
@@ -1536,7 +1540,7 @@ snd_info *add_sound_window(char *filename, read_only_t read_only, file_info *hdr
     }
   else old_chans = 0;
 
-  make_widgets = (ss->sounds[snd_slot] == NULL);
+  make_widgets = (!ss->sounds[snd_slot]);
   ss->sounds[snd_slot] = make_snd_info(ss->sounds[snd_slot], filename, hdr, snd_slot, read_only);
   sp = ss->sounds[snd_slot];
   sp->inuse = SOUND_NORMAL;
@@ -1544,13 +1548,13 @@ snd_info *add_sound_window(char *filename, read_only_t read_only, file_info *hdr
   sp->write_date = file_write_date(filename); /* needed early in this process by the peak-env handlers */
   make_pixmaps();
 
-  if (sp->snd_widgets == NULL)
+  if (!sp->snd_widgets)
     {
       sp->snd_widgets = (GtkWidget **)calloc(NUM_SND_WIDGETS, sizeof(GtkWidget *));
       sp->snd_adjs = (GtkAdjustment **)calloc(NUM_SND_ADJS, sizeof(GtkAdjustment *));
     }
 
-  if (!(auto_resize(ss))) gtk_window_set_resizable(GTK_WINDOW(MAIN_SHELL(ss)), false);
+  if (!(auto_resize(ss))) gtk_window_set_resizable(GTK_WINDOW(main_shell(ss)), false);
   if ((!make_widgets) && (old_chans < nchans))
     {
       for (i = old_chans; i < nchans; i++) 
@@ -1580,14 +1584,14 @@ snd_info *add_sound_window(char *filename, read_only_t read_only, file_info *hdr
 	      GtkWidget *tablab;
 	      tablab = gtk_label_new(sp->short_filename);
 	      gtk_widget_show(tablab);
-	      gtk_notebook_append_page(GTK_NOTEBOOK(SOUND_PANE_BOX(ss)), SND_PANE(sp), tablab);
+	      gtk_notebook_append_page(GTK_NOTEBOOK(sound_pane_box(ss)), SND_PANE(sp), tablab);
 	    }
-	  else gtk_box_pack_start(GTK_BOX(SOUND_PANE_BOX(ss)), SND_PANE(sp), true, true, 0);
+	  else gtk_box_pack_start(GTK_BOX(sound_pane_box(ss)), SND_PANE(sp), true, true, 0);
 	  /* child2 is listener */
 	}
 
       PANE_BOX(sp) = gtk_vbox_new(false, 0);
-      gtk_paned_add1(GTK_PANED(SND_PANE(sp)), PANE_BOX(sp));
+      gtk_paned_pack1(GTK_PANED(SND_PANE(sp)), PANE_BOX(sp), false, false); /* not add1 as of gtk 3.18.9 (Tito Latini) */
       gtk_widget_show(PANE_BOX(sp));
 
       NAME_HBOX(sp) = gtk_hbox_new(false, 0);
@@ -1996,11 +2000,11 @@ snd_info *add_sound_window(char *filename, read_only_t read_only, file_info *hdr
       gtk_label_set_text(GTK_LABEL(NAME_BUTTON(sp)), shortname_indexed(sp));
       reset_user_int_data(G_OBJECT(SND_PANE(sp)), sp->index); /* is this necessary? */
       if (sound_style(ss) == SOUNDS_IN_NOTEBOOK) 
-	gtk_notebook_set_tab_label_text(GTK_NOTEBOOK(SOUND_PANE_BOX(ss)), SND_PANE(sp), sp->short_filename);
+	gtk_notebook_set_tab_label_text(GTK_NOTEBOOK(sound_pane_box(ss)), SND_PANE(sp), sp->short_filename);
       else reset_controls(sp); /* segfault here in notebook case! */
     }
 
-  gtk_window_set_resizable(GTK_WINDOW(MAIN_SHELL(ss)), true);
+  gtk_window_set_resizable(GTK_WINDOW(main_shell(ss)), true);
   if (currently_showing_controls) show_controls(sp); else hide_controls(sp);
 
   if (sound_style(ss) == SOUNDS_IN_SEPARATE_WINDOWS)
@@ -2040,14 +2044,14 @@ snd_info *add_sound_window(char *filename, read_only_t read_only, file_info *hdr
   after_open(sp);
   if (sound_style(ss) == SOUNDS_IN_NOTEBOOK) 
     {
-      sp->page = gtk_notebook_page_num(GTK_NOTEBOOK(SOUND_PANE_BOX(ss)), SND_PANE(sp));
+      sp->page = gtk_notebook_page_num(GTK_NOTEBOOK(sound_pane_box(ss)), SND_PANE(sp));
       reset_controls(sp);
     }
   if (free_filename) free(filename);
   
 #if GTK_CHECK_VERSION(3, 0, 0)
   if (listener_exists())
-    gtk_paned_set_position(GTK_PANED(SOUND_PANE(ss)), 50);
+    gtk_paned_set_position(GTK_PANED(sound_pane(ss)), 50);
   /* actually we haven't reached full size here at start-up */
 #endif
   return(sp);
@@ -2056,7 +2060,7 @@ snd_info *add_sound_window(char *filename, read_only_t read_only, file_info *hdr
 
 void set_sound_pane_file_label(snd_info *sp, const char *str)
 {
-  if ((sp->name_string == NULL) || 
+  if ((!sp->name_string) || 
       (strcmp(sp->name_string, str) != 0))
     {
       if (sp->name_string) free(sp->name_string);
@@ -2102,7 +2106,7 @@ void show_controls(snd_info *sp)
 {
   gtk_widget_show_all(CONTROL_PANEL(sp));
   /* control panel is pane 2 of SND_PANE(sp); PANE_BOX is pane 1 */
-  /* gtk_paned_set_position(GTK_PANED(SOUND_PANE(ss)), (gint)(widget_height(SOUND_PANE(ss)) * .75)); (glistener) */
+  /* gtk_paned_set_position(GTK_PANED(sound_pane(ss)), (gint)(widget_height(sound_pane(ss)) * .75)); (glistener) */
 }
 
 
@@ -2235,12 +2239,12 @@ void reflect_sound_selection(snd_info *sp)
   if (sound_style(ss) == SOUNDS_IN_NOTEBOOK) 
     {
       int page, current_page;
-      current_page = gtk_notebook_get_current_page(GTK_NOTEBOOK(SOUND_PANE_BOX(ss)));
+      current_page = gtk_notebook_get_current_page(GTK_NOTEBOOK(sound_pane_box(ss)));
       page = sp->page;
       if ((page != current_page) && (current_page >= 0))
 	{
 	  ss->selected_sound = sp->index; /* break infinite recursion here */
-	  gtk_notebook_set_current_page(GTK_NOTEBOOK(SOUND_PANE_BOX(ss)), page);
+	  gtk_notebook_set_current_page(GTK_NOTEBOOK(sound_pane_box(ss)), page);
 	}
     }
 }
@@ -2370,7 +2374,7 @@ void make_controls_dialog(void)
 
       controls_dialog = snd_gtk_dialog_new();
 #if GTK_CHECK_VERSION(3, 14, 0)
-      gtk_window_set_transient_for(GTK_WINDOW(controls_dialog), GTK_WINDOW(MAIN_SHELL(ss)));
+      gtk_window_set_transient_for(GTK_WINDOW(controls_dialog), GTK_WINDOW(main_shell(ss)));
 #endif
       SG_SIGNAL_CONNECT(controls_dialog, "delete_event", delete_controls_dialog, NULL);
       gtk_window_set_title(GTK_WINDOW(controls_dialog), "Controls");
@@ -2430,7 +2434,7 @@ pane-box (10)name-form"
   Snd_assert_sound(S_sound_widgets, snd, 1);
 
   sp = get_sp(snd);
-  if (sp == NULL)
+  if (!sp)
     return(snd_no_such_sound_error(S_sound_widgets, snd));
   if (!has_widgets(sp))
     return(Xen_empty_list);
