@@ -408,31 +408,30 @@
 ;;; adds a label to the status-area area showing the current free space 
   
   (define show-disk-space
-    (let ((labelled-snds ()))
-      
-      (define (kmg num)
-	(cond ((<= num 0)      (copy "disk full!"))
-	      ((<= num 1024)   (format #f "space: ~10DK" num))
-	      ((> num 1048576) (format #f "space: ~6,3FG" (/ num (* 1024.0 1024.0))))
-	      (else            (format #f "space: ~6,3FM" (/ num 1024.0)))))
-      
-      (define (show-label data)
-	(if (sound? (car data))
-	    (let ((space (kmg (disk-kspace (file-name (car data))))))
-	      (gtk_label_set_text (GTK_LABEL (cadr data)) space)
-	      (g_timeout_add 10000 show-label data) ; every 10 seconds recheck space
-	      0)))
-      
-      (define (find-if pred lst)
-	(cond ((null? lst) #f)
-	      ((pred (car lst)) (car lst))
-	      (else (find-if pred (cdr lst)))))
-      
+    (let ((labelled-snds ())
+	  
+	  (kmg (lambda (num)
+		 (cond ((<= num 0)      (copy "disk full!"))
+		       ((<= num 1024)   (format #f "space: ~10DK" num))
+		       ((> num 1048576) (format #f "space: ~6,3FG" (/ num (* 1024.0 1024.0))))
+		       (else            (format #f "space: ~6,3FM" (/ num 1024.0))))))
+	  
+	  (show-label (lambda (data)
+			(if (sound? (car data))
+			    (let ((space (kmg (disk-kspace (file-name (car data))))))
+			      (gtk_label_set_text (GTK_LABEL (cadr data)) space)
+			      (g_timeout_add 10000 show-label data) ; every 10 seconds recheck space
+			      0)))))
       (lambda (hook)
 	;; (show-disk-space snd) adds a label to snd's status-area area showing the current free space (for use with after-open-hook)
 	
 	(let* ((snd (hook 'snd))
-	       (previous-label (find-if (lambda (n) (equal? (car n) snd)) labelled-snds)))
+	       (previous-label (let find-if ((pred (lambda (n)
+						     (equal? (car n) snd)))
+					     (lst labelled-snds))
+				 (cond ((null? lst) #f)
+				       ((pred (car lst)) (car lst))
+				       (else (find-if pred (cdr lst)))))))
 	  (if (not previous-label)
 	      (if (not snd)
 		  (snd-error "no sound found for disk space label")
@@ -552,19 +551,17 @@
   
   (define select-file
     
-    (let ((file-selector-dialogs ()))
-      ;; (list (list widget inuse func title help) ...)
-      
-      (define (find-free-dialog ds)
-	(and (pair? ds)
-	     (pair? (car ds))
-	     (pair? (cdar ds))
-	     (if (cadar ds)
-		 (find-free-dialog (cdr ds))
-		 (begin
-		   (set! ((car ds) 1) #t)
-		   (caar ds)))))
-
+    (letrec ((file-selector-dialogs ())   ; (list (list widget inuse func title help) ...)
+	     (find-free-dialog 
+	      (lambda (ds)
+		(and (pair? ds)
+		     (pair? (car ds))
+		     (pair? (cdar ds))
+		     (if (cadar ds)
+			 (find-free-dialog (cdr ds))
+			 (begin
+			   (set! ((car ds) 1) #t)
+			   (caar ds)))))))
       (lambda args
 	;; (file-select func title dir filter help)
 	(let* ((func (and (pair? args) (args 0)))
@@ -583,7 +580,7 @@
 	      (func (gtk_file_chooser_get_filename (GTK_FILE_CHOOSER dialog))))
 	  (gtk_widget_hide (GTK_WIDGET dialog))))))
   
-  ;;(select-file (lambda (n) (snd-print n)))
+  ;; ((*gtk* 'select-file) (lambda (n) (snd-print n)))
   
   
   
@@ -832,43 +829,44 @@
 	     (list (sound->integer snd) (channel-data snd 0))))
 	  (else #f)))))
   
-  (define (variable-display var widget)
-    
-    (define (force-update wid)
-      (gdk_window_invalidate_rect (GDK_WINDOW (gtk_widget_get_window (GTK_WIDGET wid))) (list 'GdkRectangle_ 0) #t)
-      (gdk_window_process_updates (GDK_WINDOW (gtk_widget_get_window (GTK_WIDGET wid))) #t))
-    
-    (define (widget? w) (and (pair? w) (= (length w) 2) (eq? (car w) 'GtkWidget_)))
-    
-    ;; (let ((wid1 (make-variable-display "do-loop" "i*1" 'spectrum))) (variable-display 0.1 wid1))
-    
-    (if (widget? widget)
-	(if (GTK_IS_LABEL widget)
-	    (begin
-	      (gtk_label_set_text (GTK_LABEL widget) (object->string var))
-	      (force-update widget)))
-	
-	(when (and (pair? widget)
-		   (or (number? (car widget))
-		       (sound? (car widget))))
-	  ;; graph/spectrum -- does this need an explicit update?
-	  (let ((snd (car widget))
-		(data (cadr widget)))
-	    (let ((len (length data))
-		  (loc (cursor snd 0)))
-	      (set! (data loc) var)
-	      (if (time-graph? snd) (update-time-graph snd))
-	      (if (transform-graph? snd) (update-transform-graph snd))
-	      (set! (cursor snd 0) (if (= (+ loc 1) len) 0 (+ loc 1))))
-	    (if (GTK_IS_PROGRESS_BAR (car widget))
-		;; "thermometer"
-		(let ((y0 (cadr widget))
-		      (y1 (caddr widget)))
-		  ;; (define wid (make-variable-display "do-loop" "i*2" 'scale))
-		  (gtk_progress_bar_set_fraction 
-		   (GTK_PROGRESS_BAR (car widget))
-		   (max 0.0 (min 1.0 (/ (- var y0) (- y1 y0))))))))))
-    var)
+  (define variable-display 
+    (let ((force-update (lambda (wid)
+			  (gdk_window_invalidate_rect (GDK_WINDOW (gtk_widget_get_window (GTK_WIDGET wid))) (list 'GdkRectangle_ 0) #t)
+			  ;;(gdk_window_process_updates (GDK_WINDOW (gtk_widget_get_window (GTK_WIDGET wid))) #t)
+			  ))
+	  (widget? (lambda (w) 
+		     (and (pair? w) 
+			  (= (length w) 2)
+			  (eq? (car w) 'GtkWidget_)))))
+      ;; (let ((wid1 (make-variable-display "do-loop" "i*1" 'spectrum))) (variable-display 0.1 wid1))
+      (lambda (var widget)
+	(if (widget? widget)
+	    (if (GTK_IS_LABEL widget)
+		(begin
+		  (gtk_label_set_text (GTK_LABEL widget) (object->string var))
+		  (force-update widget)))
+	    
+	    (when (and (pair? widget)
+		       (or (number? (car widget))
+			   (sound? (car widget))))
+	      ;; graph/spectrum -- does this need an explicit update?
+	      (let ((snd (car widget))
+		    (data (cadr widget)))
+		(let ((len (length data))
+		      (loc (cursor snd 0)))
+		  (set! (data loc) var)
+		  (if (time-graph? snd) (update-time-graph snd))
+		  (if (transform-graph? snd) (update-transform-graph snd))
+		  (set! (cursor snd 0) (if (= (+ loc 1) len) 0 (+ loc 1))))
+		(if (GTK_IS_PROGRESS_BAR (car widget))
+		    ;; "thermometer"
+		    (let ((y0 (cadr widget))
+			  (y1 (caddr widget)))
+		      ;; (define wid (make-variable-display "do-loop" "i*2" 'scale))
+		      (gtk_progress_bar_set_fraction 
+		       (GTK_PROGRESS_BAR (car widget))
+		       (max 0.0 (min 1.0 (/ (- var y0) (- y1 y0))))))))))
+	var)))
 
   (define (notebook-with-top-tabs)
     (gtk_notebook_set_tab_pos (GTK_NOTEBOOK ((main-widgets) 5)) GTK_POS_TOP))
