@@ -1,6 +1,12 @@
 #include "snd.h"
 
 
+#if GTK_CHECK_VERSION(3, 22, 0)
+  /* surely nothing can go wrong... */
+  static GdkWindow *last_window = NULL;
+  static GdkDrawingContext *last_context = NULL;
+#endif
+
 #if GTK_CHECK_VERSION(3, 0, 0)
 cairo_t *make_cairo(GdkWindow *win)
 #else
@@ -8,13 +14,23 @@ cairo_t *make_cairo(GdkDrawable *win)
 #endif
 {
   ss->line_width = -1.0;
+#if GTK_CHECK_VERSION(3, 22, 0)
+  last_window = win;
+  last_context = gdk_window_begin_draw_frame(win, gdk_window_get_visible_region(win));
+  return(gdk_drawing_context_get_cairo_context(last_context));
+#else
   return(gdk_cairo_create(win));
+#endif
 }
 
 void free_cairo(cairo_t *cr)
 {
   ss->line_width = -1.0;
+#if GTK_CHECK_VERSION(3, 22, 0)
+  gdk_window_end_draw_frame(last_window, last_context);
+#else
   cairo_destroy(cr);
+#endif
 }
 
 
@@ -126,7 +142,7 @@ int sg_text_width(const char *txt, PangoFontDescription *font)
   int wid = 0;
   PangoLayout *layout = NULL;
   PangoContext *ctx;
-  if (txt == NULL) return(0);
+  if (!txt) return(0);
   if (mus_strlen(txt) == 0) return(0);
   if (!(g_utf8_validate(txt, -1, NULL)))
     return(0);
@@ -425,7 +441,7 @@ void check_for_event(void)
 
 void set_title(const char *title)
 {
-  gtk_window_set_title(GTK_WINDOW(MAIN_SHELL(ss)), title);
+  gtk_window_set_title(GTK_WINDOW(main_shell(ss)), title);
 }
 
 
@@ -856,7 +872,7 @@ GtkWidget *snd_gtk_dialog_new(void)
   GtkWidget *w;
   w = gtk_dialog_new();
 #if GTK_CHECK_VERSION(3, 14, 0)
-  gtk_window_set_transient_for(GTK_WINDOW(w), GTK_WINDOW(MAIN_SHELL(ss)));
+  gtk_window_set_transient_for(GTK_WINDOW(w), GTK_WINDOW(main_shell(ss)));
 #endif
   add_dialog_style(w);
   g_object_ref(w); 
@@ -965,7 +981,7 @@ static gboolean slist_item_button_pressed(GtkWidget *w, GdkEventButton *ev, gpoi
 }
 
 
-#if GTK_CHECK_VERSION(3, 0, 0)
+#if ((GTK_CHECK_VERSION(3, 0, 0)) && (!(GTK_CHECK_VERSION(3, 89, 0))))
 static GtkCssProvider *wb_provider, *listener_provider, *dialog_provider, *hl_provider, *tb_provider, *mu_provider;
 static GtkCssProvider *rsc_provider, *gsc_provider, *bsc_provider, *pd_provider, *cb_provider, *entry_provider;
 static GtkCssProvider *cl_provider;
@@ -1302,7 +1318,7 @@ void slist_append(slist *lst, const char *name)
       for (i = lst->num_items; i < lst->items_size; i++) lst->items[i] = NULL;
     }
   loc = lst->num_items++;
-  if (lst->items[loc] == NULL)
+  if (!lst->items[loc])
     lst->items[loc] = slist_new_item(lst, name, loc);
   else 
     {
@@ -1447,6 +1463,10 @@ widget \"*.white_button\" style \"white_button\"\n");
 
 #else
 
+#if (GTK_CHECK_VERSION(3, 89, 0))
+/* border-width and -gtk-gradient have been removed, and as far as I can tell, this stuff never works anyway */
+void init_gtk(void) {return;}
+#else
 void init_gtk(void)
 {
   wb_provider = gtk_css_provider_new();
@@ -1595,5 +1615,5 @@ void init_gtk(void)
  */
 }
 #endif
-
+#endif
 
