@@ -913,7 +913,7 @@ static char *xen_colormap_to_string(xen_colormap *v)
 {
   #define COLORMAP_PRINT_BUFFER_SIZE 64
   char *buf;
-  if (v == NULL) return(NULL);
+  if (!v) return(NULL);
   buf = (char *)calloc(COLORMAP_PRINT_BUFFER_SIZE, sizeof(char));
   snprintf(buf, COLORMAP_PRINT_BUFFER_SIZE, "#<colormap %s>", colormap_name(v->n));
   return(buf);
@@ -1032,8 +1032,12 @@ static void init_xen_colormap(void)
 static Xen g_integer_to_colormap(Xen n)
 {
   #define H_integer_to_colormap "(" S_integer_to_colormap " n) returns a colormap object corresponding to the given integer"
+  int id;
   Xen_check_type(Xen_is_integer(n), n, 1, S_integer_to_colormap, "an integer");
-  return(new_xen_colormap(Xen_integer_to_C_int(n)));
+  id = Xen_integer_to_C_int(n);
+  if (is_colormap(id))
+    return(new_xen_colormap(id));
+  return(Xen_false);
 }
 
 
