@@ -26,6 +26,12 @@
 			(mus-sound-data-format . mus-sound-sample-type)
 			(mus-data-format-name . mus-sample-type-name)
 			(mus-data-format->string . mus-sample-type->string)
+			(default-output-data-format . default-output-sample-type)
+			(channel->vct . channel->float-vector)
+			(vct->channel . float-vector->channel)
+			(region->vct . region->float-vector)
+			(mix->vct . mix->float-vector)
+			(transform->vct . transform->float-vector)
 			(make-vct . make-float-vector)
 			(vct-add! . float-vector-add!)
 			(vct-subtract! . float-vector-subtract!)
@@ -39,6 +45,7 @@
 			(vct-fill! . fill!)
 			(vct-set! . float-vector-set!)
 			(vct-peak . float-vector-peak)
+			(vct-peak-and-location . float-vector-peak-and-location)
 			(vct-equal? . equal?)
 			(vct? . float-vector?)
 			(list->vct . list->float-vector)
@@ -74,14 +81,14 @@
   (define (get-generator caller form env)
     (with-let (sublet *lint* :caller caller :form form :env env)
       (when (pair? (cdr form))
-	(let ((name ((if (pair? (cadr form)) caadr cadr) form)))
+	(let ((name (symbol->string ((if (pair? (cadr form)) caadr cadr) form))))
 	  
 	  (if (and (pair? (cadr form))
 		   (pair? (cdadr form)))
 	      (lint-walk caller (cdadr form) env))
 	  
-	  (let ((gen? (symbol (symbol->string name) "?"))
-		(gen-make (symbol "make-" (symbol->string name))))
+	  (let ((gen? (symbol name "?"))
+		(gen-make (symbol "make-" name)))
 	    (list (make-fvar :name gen?
 			     :ftype 'define
 			     :decl (dummy-func 'define `(define (,gen? x) (let? x)) '(define (_ x) #f))
@@ -129,7 +136,7 @@
      fffneq ffneq fft-log-frequency fft-log-magnitude fft-window fft-window-alpha
      fft-window-beta fft-with-phases file->frample? file->sample? file-name file-write-date filter-control-coeffs filter-control-envelope
      filter-control-in-dB filter-control-in-hz filter-control-order filter-control-waveform-color filter-control? filter? filtered-comb-bank?
-     filtered-comb? find-dialog find-mark find-sound fir-filter? firmant?  float-vector-equal? float-vector-max float-vector-min float-vector-peak
+     filtered-comb? find-dialog find-mark find-sound fir-filter? firmant? float-vector-equal? float-vector-max float-vector-min float-vector-peak
      float-vector-peak-and-location fneq foreground-color formant-bank? formant? frample
      framples ftell fveql get-internal-real-time getcwd getpid granulate? graph-color graph-cursor
      graph-style graphs-horizontal grid-density gsl-ellipj gsl-ellipk gsl-roots header-type html-dir html-program hz->radians
@@ -138,6 +145,15 @@
      ladspa-dir left-sample lgamma linear->db lisp-graph-style lisp-graph?
      listener-color listener-colorized listener-font listener-prompt listener-selection listener-text-color little-endian?
      localtime locsig-ref locsig-reverb-ref locsig-type locsig? log-freq-start main-menu main-widgets 
+
+     make-env make-pulsed-env make-one-pole make-fir-coeffs make-formant make-all-pass-bank make-iir-filter make-filter 
+     make-comb make-polywave make-bezier make-delay make-nrxycos make-moving-norm make-nrxysin make-firmant make-cairo 
+     make-sawtooth-wave make-color make-graph-data make-oscil make-oscil-bank make-two-zero make-fft-window make-moving-max 
+     make-filtered-comb-bank make-filtered-comb make-nsin make-rand-interp make-one-pole-all-pass make-rand make-formant-bank 
+     make-all-pass make-table-lookup make-one-zero make-notch make-square-wave make-moving-average make-polyshape
+     make-triangle-wave make-comb-bank make-ncos make-rxyk!sin make-fir-filter make-two-pole make-asymmetric-fm 
+     make-rxyk!cos make-pulse-train 
+
      mark->integer mark-color mark-home mark-hook mark-name mark-properties
      mark-property mark-sample mark-sync mark-sync-max mark-tag-height mark-tag-width mark?
      marks max-regions max-transform-peaks maxamp maxamp-position menu-widgets min-dB mix->integer mix-color mix-dialog-mix mix-drag-hook mix-home
@@ -167,7 +183,7 @@
      sawtooth-wave? script-arg script-args search-procedure seconds->samples selected-channel selected-data-color
      selected-graph-color selected-sound selection selection-chans selection-creates-region selection-framples selection-maxamp
      selection-maxamp-position selection-member? selection-position selection-srate selection? short-file-name
-     sinc-width singer-filter singer-nose-filter snd->sample?  snd-gcs snd-global-state snd-help snd-tempnam
+     sinc-width singer-filter singer-nose-filter snd->sample? snd-gcs snd-global-state snd-help snd-tempnam
      snd-url snd-urls snd-version sound->integer sound-file-extensions sound-file?
      sound-files-in-directory sound-loop-info sound-properties sound-property sound-widgets sound? soundfont-info
      sounds spectro-hop spectro-x-angle spectro-x-scale spectro-y-angle spectro-y-scale spectro-z-angle
@@ -185,6 +201,22 @@
      zoom-focus-style zoom-one-pixel)))
 
 
+;;; ---------------- Snd makers ----------------
+(let ((h (*lint* 'makers)))
+  (for-each
+   (lambda (s)
+     (hash-table-set! h s #t))
+   '(make-env make-pulsed-env make-one-pole make-fir-coeffs make-convolve make-wave-train make-formant make-all-pass-bank 
+     make-iir-filter make-filter make-comb make-sample->file make-polywave make-bezier make-delay make-nrxycos make-moving-norm 
+     make-nrxysin make-firmant make-cairo make-sawtooth-wave make-color make-player make-graph-data make-oscil make-oscil-bank 
+     make-two-zero make-fft-window make-moving-max make-filtered-comb-bank make-filtered-comb make-nsin make-rand-interp 
+     make-one-pole-all-pass make-rand make-formant-bank make-readin make-all-pass make-phase-vocoder make-table-lookup 
+     make-one-zero make-notch make-square-wave make-file->frample make-moving-average make-granulate make-polyshape 
+     make-locsig make-triangle-wave make-mix-sampler make-move-sound make-comb-bank make-ncos make-rxyk!sin 
+     make-variable-graph make-fir-filter make-file->sample make-ssb-am make-two-pole make-region-sampler 
+     make-frample->file make-asymmetric-fm make-sampler make-region make-snd->sample make-src make-rxyk!cos make-pulse-train)))
+
+
 ;;; ---------------- Snd booleans ----------------
 ;;; add Snd/clm type checkers to lint's table (lint assumes that these take one argument)
 
@@ -198,4 +230,3 @@
 	    two-zero? wave-train? file->frample? frample->file?
 
 	    mark? mix? mix-sampler? region?))
-
