@@ -338,7 +338,7 @@ static void ps_set_color(color_t color)
   Colormap cmap;
   XColor tmp_color;
   Display *dpy;
-  dpy = XtDisplay(MAIN_SHELL(ss));
+  dpy = XtDisplay(main_shell(ss));
   cmap = DefaultColormap(dpy, DefaultScreen(dpy));
   tmp_color.flags = DoRed | DoGreen | DoBlue;
   tmp_color.pixel = color;
@@ -370,7 +370,7 @@ void ps_bg(axis_info *ap, graphics_context *ax)
 #if USE_MOTIF
   {
     XGCValues gv;
-    XGetGCValues(MAIN_DISPLAY(ss), ax->gc, GCBackground, &gv);
+    XGetGCValues(main_display(ss), ax->gc, GCBackground, &gv);
     ps_set_color(gv.background);
   }
 #else
@@ -517,7 +517,7 @@ static char *snd_print_or_error(const char *output)
       chan_info *ccp;
       char *errstr = NULL;
       ccp = current_channel();
-      if (ccp == NULL) 
+      if (!ccp) 
 	return(mus_strdup("nothing to print?"));
       si = sync_to_chan(ccp);
       offsets = (int *)calloc(si->chans, sizeof(int));
@@ -531,7 +531,7 @@ static char *snd_print_or_error(const char *output)
 	  {
 	    snd_info *sp;
 	    sp = (si->cps[i])->sound;
-	    if (sp == NULL) break;
+	    if (!sp) break;
 	    if (sp->channel_style == CHANNELS_COMBINED)
 	      for (j = i + 1; (j < i + sp->nchans) && (j < si->chans); j++) 
 		offsets[j] = offsets[i];
