@@ -54,7 +54,7 @@ typedef struct region {
   int id;
   deferred_region *dr;      /* REGION_DEFERRED descriptor */
   peak_env_info **peak_envs;
-  mus_long_t *begs, *lens;
+  mus_long_t *begs, *ends;
 } region;
 
 
@@ -78,7 +78,7 @@ static void free_region(region *r, int complete)
 	  if (r->start) free(r->start);
 	  if (r->end) free(r->end);
 	  if (r->begs) free(r->begs);
-	  if (r->lens) free(r->lens);
+	  if (r->ends) free(r->ends);
 	  if (r->peak_envs)
 	    {
 	      int i;
@@ -189,7 +189,7 @@ static region *id_to_region(int id)
 
 bool region_ok(int id) 
 {
-  return(id_to_region(id) != NULL);
+  return((bool)id_to_region(id));
 }
 
 
@@ -619,7 +619,7 @@ static int paste_region_1(int n, chan_info *cp, bool add, mus_long_t beg, io_err
   sync_info *si = NULL;
 
   r = id_to_region(n);
-  if ((r == NULL) || 
+  if ((!r) || 
       (r->framples == 0)) 
     return(INVALID_REGION);
 
@@ -774,7 +774,7 @@ int define_region(sync_info *si, mus_long_t *ends)
   r->end = prettyf((double)(ends[0]) / (double)(r->srate), 2);
   r->use_temp_file = REGION_DEFERRED;
   r->begs = (mus_long_t *)calloc(r->chans, sizeof(mus_long_t));
-  r->lens = (mus_long_t *)calloc(r->chans, sizeof(mus_long_t));
+  r->ends = (mus_long_t *)calloc(r->chans, sizeof(mus_long_t));
 
   ss->deferred_regions++;
   r->dr = (deferred_region *)calloc(1, sizeof(deferred_region));
@@ -788,17 +788,17 @@ int define_region(sync_info *si, mus_long_t *ends)
     {
       drp->cps[i] = si->cps[i];
       r->begs[i] = si->begs[i];
-      r->lens[i] = ends[i] - si->begs[i];
+      r->ends[i] = ends[i] - si->begs[i];
       drp->edpos[i] = drp->cps[i]->edit_ctr;
-      if (r->lens[i] > PEAK_ENV_CUTOFF)
+      if (r->ends[i] > PEAK_ENV_CUTOFF)
 	{
 	  peak_env_info *ep;
 	  ep = drp->cps[i]->edits[drp->edpos[i]]->peak_env;
 	  if ((ep) && (ep->completed))
 	    {
-	      if (r->peak_envs == NULL)
+	      if (!r->peak_envs)
 		r->peak_envs = (peak_env_info **)calloc(r->chans, sizeof(peak_env_info *));
-	      r->peak_envs[i] = peak_env_section(drp->cps[i], r->begs[i], r->lens[i], drp->edpos[i]);
+	      r->peak_envs[i] = peak_env_section(drp->cps[i], r->begs[i], r->ends[i] + 1, drp->edpos[i]);
 	    }
 	}
     }
@@ -828,15 +828,15 @@ static void deferred_region_to_temp_file(region *r)
 
   copy_ok = ((mus_header_writable(MUS_NEXT, sp0->hdr->sample_type)) && 
 	     (r->chans == sp0->nchans) &&
-	     (r->peak_envs != NULL) &&
-	     ((drp->len - 1) == r->lens[0]));
+	     (r->peak_envs) &&
+	     ((drp->len - 1) == r->ends[0]));
   if (copy_ok)
     for (i = 0; i < r->chans; i++)
       if ((drp->edpos[i] != 0) || 
 	  (drp->cps[i]->sound != sp0) ||
 	  (r->begs[i] != r->begs[0]) ||
-	  (r->lens[i] != (drp->len - 1)) ||
-	  (r->peak_envs[i] == NULL))
+	  (r->ends[i] != (drp->len - 1)) ||
+	  (!r->peak_envs[i]))
 	{
 	  copy_ok = false;
 	  break;
@@ -934,7 +934,7 @@ static void deferred_region_to_temp_file(region *r)
 	    }
 
 	  if ((r->chans == 1) &&
-	      (r->lens[0] == (len - 1)))
+	      (r->ends[0] == (len - 1)))
 	    {
 	      snd_fd *sf;
 	      mus_float_t *d;
@@ -1028,10 +1028,10 @@ void sequester_deferred_regions(chan_info *cp, int edit_top)
 	    if ((drp->cps[j] == cp) &&
 		(drp->edpos[j] > edit_top))
 	      {
-		if (r->lens[j] > 1000000)
+		if (r->ends[j] > 1000000)
 		  status_report(cp->sound, "sequestering region %d...", r->id);
 		deferred_region_to_temp_file(r);
-		if (r->lens[j] > 1000000)
+		if (r->ends[j] > 1000000)
 		  clear_status_area(cp->sound);
 		break;
 	      }
@@ -1250,12 +1250,17 @@ void save_region_backpointer(snd_info *sp)
       val = channel_maxamp(sp->chans[i], AT_CURRENT_EDIT_POSITION);
       if (val > r->maxamp) r->maxamp = val;
 
-      if (r->lens[i] > PEAK_ENV_CUTOFF)
+      if (r->ends[i] > PEAK_ENV_CUTOFF)
         {
           chan_info *cp;
           cp = sp->chans[i];
-          if (r->peak_envs[i])
-            free_peak_env_info(r->peak_envs[i]);
+          if (!r->peak_envs)
+            r->peak_envs = (peak_env_info **)calloc(r->chans, sizeof(peak_env_info *));
+          else 
+	    {
+	      if (r->peak_envs[i])
+		free_peak_env_info(r->peak_envs[i]);
+	    }
           /* if region file was edited, the peak_envs probably changed */
           r->peak_envs[i] = copy_peak_env_info(cp->edits[0]->peak_env, false);
         }
@@ -1410,7 +1415,7 @@ static char *xen_region_to_string(xen_region *v)
 {
   #define REGION_PRINT_BUFFER_SIZE 64
   char *buf;
-  if (v == NULL) return(NULL);
+  if (!v) return(NULL);
   buf = (char *)calloc(REGION_PRINT_BUFFER_SIZE, sizeof(char));
   snprintf(buf, REGION_PRINT_BUFFER_SIZE, "#<region %d>", v->n);
   return(buf);
@@ -1518,8 +1523,12 @@ static void init_xen_region(void)
 static Xen g_integer_to_region(Xen n)
 {
   #define H_integer_to_region "(" S_integer_to_region " n) returns a region object corresponding to the given integer"
+  region* r;
   Xen_check_type(Xen_is_integer(n), n, 1, S_integer_to_region, "an integer");
-  return(new_xen_region(Xen_integer_to_C_int(n)));
+  r = id_to_region(Xen_integer_to_C_int(n));
+  if (r)
+    return(new_xen_region(r->id));
+  return(Xen_false);
 }
 
 
@@ -1547,7 +1556,7 @@ static Xen g_restore_region(Xen args)
 {
   /* internal function used by save-state mechanism -- not intended for external use */
   region *r;
-  int regn;
+  int i, regn;
   Xen arg, pos, chans, len, srate, maxamp, name, start, end, filename, date;
   
   arg = args;
@@ -1611,6 +1620,15 @@ static Xen g_restore_region(Xen args)
   r->use_temp_file = REGION_FILE;
   r->filename = mus_strdup(Xen_string_to_C_string(filename));
 
+  /* bugfix for saved regions -- thanks to Tito Latini */
+  r->begs = (mus_long_t *)calloc(r->chans, sizeof(mus_long_t));
+  r->ends = (mus_long_t *)calloc(r->chans, sizeof(mus_long_t));
+  for (i = 0; i < r->chans; i++)
+    {
+      r->begs[i] = 0;
+      r->ends[i] = r->framples - 1;
+    }
+ 
   reflect_regions_in_region_browser();
   return(C_int_to_Xen_integer(r->id));
 }
@@ -1698,7 +1716,7 @@ Xen g_region_framples(Xen n, Xen chan)
     return(snd_no_such_channel_error(S_region_framples, Xen_list_1(n), chan));
 
   r = id_to_region(rg);
-  return(C_llong_to_Xen_llong(r->lens[chn] + 1));
+  return(C_llong_to_Xen_llong(r->ends[chn] + 1));
 }
 
 
@@ -1747,7 +1765,7 @@ static Xen region_get(region_field_t field, Xen n, const char *caller)
 	if (r)
 	  return(Xen_list_3(C_string_to_Xen_string(r->name), 
 			    C_llong_to_Xen_llong(r->begs[0]), 
-			    C_llong_to_Xen_llong(r->lens[0]))); 
+			    C_llong_to_Xen_llong(r->ends[0] + 1))); 
       }
       break;
     default: break;
@@ -1925,7 +1943,7 @@ static void init_region_keywords(void)
 static void save_region_to_xen_error(const char *msg, void *data)
 {
   redirect_snd_error_to(NULL, NULL);
-  Xen_error(CANNOT_SAVE,
+  Xen_error(Xen_make_error_type("cannot-save"),
 	    Xen_list_2(C_string_to_Xen_string(S_save_region ": can't save ~S"),
 		       C_string_to_Xen_string(msg)));
 }
@@ -1967,7 +1985,7 @@ using sample-type (default depends on machine byte order), header-type (" S_mus_
       com = mus_optkey_to_string(keys[3], S_save_region, orig_arg[3], NULL);
     }
 
-  if (file == NULL) 
+  if (!file) 
     Xen_error(Xen_make_error_type("IO-error"),
 	      Xen_list_1(C_string_to_Xen_string(S_save_region ": no output file?")));
 
