@@ -844,7 +844,7 @@ int main(int argc, char **argv)
     free(s1);    
 
     s7_set_car(c1234, s7_make_symbol(sc, "+")); 
-    p = s7_eval(sc, s7_list(sc, 2, s7_make_symbol(sc, "quote"), c1234), s7_sublet(sc, s7_rootlet(sc), s7_nil(sc)));
+    p = s7_eval(sc, c1234, s7_sublet(sc, s7_rootlet(sc), s7_nil(sc)));
     if (s7_integer(p) != 9)
       {fprintf(stderr, "%d: (eval '(+ 2 3 4)) is %s?\n", __LINE__, s1 = TO_STR(p)); free(s1);}
     p = s7_eval_form(sc, c1234, s7_sublet(sc, s7_rootlet(sc), s7_nil(sc)));
@@ -1236,6 +1236,50 @@ int main(int argc, char **argv)
     s7_close_input_port(sc, port);
     s7_gc_unprotect_at(sc, gc_loc);
 
+    /* make sure s7_read does not ignore #<eof> */
+    port = s7_open_input_string(sc, "(define aaa 32)\n(define bbb 33)\n");
+    if (!s7_is_input_port(sc, port))
+      {fprintf(stderr, "%d: %s is not an input port?\n", __LINE__, s1 = TO_STR(port)); free(s1);}
+    gc_loc = s7_gc_protect(sc, port);
+    while(true)
+      {
+	s7_pointer code;
+	code = s7_read(sc, port);
+	if (code == s7_eof_object(sc)) break;
+	s7_eval(sc, code, s7_nil(sc));
+      }
+    s7_close_input_port(sc, port);
+    s7_gc_unprotect_at(sc, gc_loc);
+
+    port = s7_open_input_string(sc, "(define ccc 34)\n(define ddd 35)");
+    if (!s7_is_input_port(sc, port))
+      {fprintf(stderr, "%d: %s is not an input port?\n", __LINE__, s1 = TO_STR(port)); free(s1);}
+    gc_loc = s7_gc_protect(sc, port);
+    while(true)
+      {
+	s7_pointer code;
+	code = s7_read(sc, port);
+	if (code == s7_eof_object(sc)) break;
+	s7_eval(sc, code, s7_nil(sc));
+      }
+    s7_close_input_port(sc, port);
+    s7_gc_unprotect_at(sc, gc_loc);
+    {
+      s7_pointer val;
+      val = s7_name_to_value(sc, "aaa");
+      if ((!s7_is_integer(val)) || (s7_integer(val) != 32))
+	fprintf(stderr, "aaa: %s\n", s7_object_to_c_string(sc, val));
+      val = s7_name_to_value(sc, "bbb");
+      if ((!s7_is_integer(val)) || (s7_integer(val) != 33))
+	fprintf(stderr, "bbb: %s\n", s7_object_to_c_string(sc, val));
+      val = s7_name_to_value(sc, "ccc");
+      if ((!s7_is_integer(val)) || (s7_integer(val) != 34))
+	fprintf(stderr, "ccc: %s\n", s7_object_to_c_string(sc, val));
+      val = s7_name_to_value(sc, "ddd");
+      if ((!s7_is_integer(val)) || (s7_integer(val) != 35))
+	fprintf(stderr, "ddd: %s\n", s7_object_to_c_string(sc, val));
+    }
+
     port = s7_open_output_string(sc);
     if (!s7_is_output_port(sc, port))
       {fprintf(stderr, "%d: %s is not an output port?\n", __LINE__, s1 = TO_STR(port)); free(s1);}
@@ -1325,7 +1369,7 @@ int main(int argc, char **argv)
     s7_gc_unprotect_at(sc, gc_loc);
   }
 
-  if (s7_begin_hook(sc) != NULL)
+  if (s7_begin_hook(sc))
     {fprintf(stderr, "%d: begin_hook is not null?\n", __LINE__);}
   tested_begin_hook = false;
   s7_set_begin_hook(sc, test_begin_hook);
@@ -1460,7 +1504,8 @@ int main(int argc, char **argv)
   }
 
   {                            
-    s7_pointer old_port, result;
+    int gc_loc1;
+    s7_pointer old_port, result, func;
     const char *errmsg = NULL;
 
     s7_define_function(sc, "error-handler", test_error_handler, 1, 0, false, "our error handler");
@@ -1489,6 +1534,54 @@ int main(int argc, char **argv)
     s7_set_current_error_port(sc, old_port);
     s7_gc_unprotect_at(sc, gc_loc);
 
+
+    old_port = s7_set_current_error_port(sc, s7_open_output_string(sc));
+    gc_loc = s7_gc_protect(sc, old_port);
+
+    func = s7_eval_c_string(sc, "(lambda (x) (+ x 1))");
+    result = s7_call(sc, func, s7_list(sc, 1, s7_make_integer(sc, 2)));
+    if ((!s7_is_integer(result)) || (s7_integer(result) != 3))
+      {fprintf(stderr, "%d: s7_call (x+1) result: %s\n", __LINE__, s1 = TO_STR(result)); free(s1);}
+
+    result = s7_call(sc, func, s7_list(sc, 1, s7_make_vector(sc, 0)));
+    if (result != s7_make_symbol(sc, "our-error"))
+      {fprintf(stderr, "%d: s7_call error hook result: %s\n", __LINE__, s1 = TO_STR(result)); free(s1);}
+    errmsg = s7_get_output_string(sc, s7_current_error_port(sc));
+    if ((errmsg) && (*errmsg))
+      {
+	if (strcmp(errmsg, "error!") != 0)
+	  fprintf(stderr, "%d: error: %s\n", __LINE__, errmsg);
+      }
+    else fprintf(stderr, "%d: no error!\n", __LINE__);
+
+    s7_close_output_port(sc, s7_current_error_port(sc));
+    s7_set_current_error_port(sc, old_port);
+    s7_gc_unprotect_at(sc, gc_loc);
+
+
+    old_port = s7_set_current_error_port(sc, s7_open_output_string(sc));
+    gc_loc = s7_gc_protect(sc, old_port);
+
+    func = s7_eval_c_string(sc, "(let ((x 0)) (list (lambda () (set! x 1)) (lambda () (set! x (+ x #()))) (lambda () (set! x (+ x 1))) (lambda () x)))");
+    gc_loc1 = s7_gc_protect(sc, func);
+    result = s7_dynamic_wind(sc, s7_car(func), s7_cadr(func), s7_caddr(func));
+
+    if (result != s7_make_symbol(sc, "our-error"))
+      {fprintf(stderr, "%d: s7_dynamic_wind error hook result: %s\n", __LINE__, s1 = TO_STR(result)); free(s1);}
+    errmsg = s7_get_output_string(sc, s7_current_error_port(sc));
+    if ((errmsg) && (*errmsg))
+      {
+	if (strcmp(errmsg, "error!") != 0)
+	  fprintf(stderr, "%d: error: %s\n", __LINE__, errmsg);
+      }
+    else fprintf(stderr, "%d: no error!\n", __LINE__);
+
+    s7_close_output_port(sc, s7_current_error_port(sc));
+    s7_set_current_error_port(sc, old_port);
+    s7_gc_unprotect_at(sc, gc_loc);
+    s7_gc_unprotect_at(sc, gc_loc1);
+
+
     s7_eval_c_string(sc, "(set! (hook-functions *error-hook*) ())");
   }
 
