@@ -509,29 +509,12 @@
 	  (arg-start 0)
 	  (line-len 0))
       
-      (define (hey-start)
-	;; start of checked line
-	(set! line-len 0))
-      
-      (define (hey-mark)
-	;; start of checked line
-	(set! arg-start line-len))
-      
       (define (hey-on . args)
 	;; no cr -- just append
 	(let ((line (apply format #f args)))
 	  (set! line-len (+ line-len (length line)))
 	  (heyc line)))
       
-      (define (hey-ok arg)
-	;; cr ok after arg
-	(set! line-len (+ line-len (length arg)))
-	(heyc arg)
-	(if (> line-len 120)
-	    (begin
-	      (format gl-file "~%~NC" arg-start #\space)
-	      (set! line-len arg-start))))
-      
       (check-glu name)
       (if (member name glu-1-2) (hey "#ifdef GLU_VERSION_1_2~%"))
       
@@ -611,7 +594,7 @@
 	    (begin
 	      (hey "  {~%")
 	      (hey "    Xen result;~%")))
-	(hey-start)
+	(set! line-len 0)
 	(if (string=? return-type "void")
 	    (hey-on "  ")
 	    (hey-on (if (= refargs 0)
@@ -620,14 +603,22 @@
 		    (no-stars return-type)))
 	
 	(hey-on "~A(" name)
-	(hey-mark)
+	(set! arg-start line-len)
 	(if (> argslen 0)
 	    (let ((previous-arg #f))
 	      (for-each
 	       (lambda (arg)
 		 (let ((argname (cadr arg))
 		       (argtype (car arg)))
-		   (if previous-arg (hey-ok ", "))
+		   (if previous-arg 
+		       (let ((arg ", "))
+			 ;; cr ok after arg
+			 (set! line-len (+ line-len (length arg)))
+			 (heyc arg)
+			 (if (> line-len 120)
+			     (begin
+			       (format gl-file "~%~NC" arg-start #\space)
+			       (set! line-len arg-start)))))
 		   (if (and (not previous-arg)
 			    (> (length data) 4)
 			    (eq? (data 4) 'const))
@@ -738,22 +729,23 @@
 			string=?) => cdr)
 		(#t #t))))))
 	       
-(define (make-signature fnc)
-  (define (compress sig)
-    (do ((sig sig (cdr sig)))
-	((not (and (pair? sig)
-		   (pair? (cdr sig))
-		   (not (and (eq? (car sig) 'pair?) (null? (cddr sig))))
-		   (eq? (car sig) (cadr sig))))
-	 sig)))
-  (let ((sig (list (if (positive? (ref-args (caddr fnc))) ; these are returned as cadr of list
-		       'pair?
-		       (gtk-type->s7-type (cadr fnc))))))
-    (for-each
-     (lambda (arg)
-       (set! sig (cons (gtk-type->s7-type (car arg)) sig)))
-     (caddr fnc))
-    (reverse (compress sig))))
+(define make-signature 
+  (let ((compress (lambda (sig)
+		    (do ((sig sig (cdr sig)))
+			((not (and (pair? sig)
+				   (pair? (cdr sig))
+				   (not (and (eq? (car sig) 'pair?) (null? (cddr sig))))
+				   (eq? (car sig) (cadr sig))))
+			 sig)))))
+    (lambda (fnc)
+      (let ((sig (list (if (positive? (ref-args (caddr fnc))) ; these are returned as cadr of list
+			   'pair?
+			   (gtk-type->s7-type (cadr fnc))))))
+	(for-each
+	 (lambda (arg)
+	   (set! sig (cons (gtk-type->s7-type (car arg)) sig)))
+	 (caddr fnc))
+	(reverse (compress sig))))))
 
 (define signatures (make-hash-table))
 (define (make-signatures lst type)
