@@ -15,6 +15,7 @@
   "`(ok? ',tst (lambda () (eval ',tst)) ,expected)"
   "`(ok? ',tst (lambda () ,tst) ,expected)"
   "`(ok? ',tst (let () (define (_s7_) ,tst)) ,expected)"
+  "`(ok? ',tst (let () (define (_s7_) ,tst) (define (_call_) (_s7_))) ,expected)"
   "`(ok? ',tst (lambda () (let ((_s7_ #f)) (set! _s7_ ,tst))) ,expected)"
   "`(ok? ',tst (lambda () (let ((_s7_ ,tst)) _s7_)) ,expected)"
   "`(ok? ',tst (catch #t (lambda () (lambda* ((_a_ ,tst)) _a_)) (lambda any (lambda () 'error))) ,expected)"
@@ -35,7 +36,7 @@
   "`(ok? ',tst (lambda () (dynamic-wind (lambda () #f) (lambda () ,tst) (lambda () #f))) ,expected)"
   "`(ok? ',tst (lambda () (caadr (catch 'receive (lambda () (throw 'receive ,tst)) (lambda any any)))) ,expected)"
   "`(ok? ',tst (lambda () (stacktrace (- (random 100) 50) (- (random 100) 50) (- (random 100) 50) (- (random 100) 50) (> (random 100) 50)) ,tst) ,expected)"
-  "({list} 'ok? ({list} quote tst) ({list} lambda () tst) expected)"
+  "(list-values 'ok? (list-values quote tst) (list-values lambda () tst) expected)"
   ))
 
 (format *stderr* "~NC ffitest ~NC~%" 20 #\- 20 #\-)
