@@ -159,7 +159,7 @@
 	      (if (symbol? (car lst))
 		  (symbol->value (car lst))
 		  (and (pair? (car lst))
-		       (apply lambda '(x) `((or (,(caar lst) x) (,(cadar lst) x)))))))))
+		       (apply lambda '(x) (list (list 'or (list (caar lst) 'x) (list (cadar lst) 'x)))))))))
 
 (define baddies '(exit emergency-exit abort autotest 
 		  all delete-file system set-cdr! stacktrace test-sym
@@ -168,7 +168,7 @@
 		  throw symbol-table load
 		  global-environment current-environment make-procedure-with-setter procedure-with-setter? make-rectangular
 		  
-		  copy fill! hash-table-set! vector-set! let-set!
+		  copy fill! hash-table-set! vector-set! let-set! list-values apply-values ; omitted { before (see below)
 		  
 		  mock-number mock-pair mock-string mock-char mock-vector 
 		  mock-symbol mock-port mock-hash-table m 
