@@ -205,7 +205,7 @@
     (do ((i 0 (+ i 1)))
 	((= i size))
       (set! strs (cons (make-string size (integer->char (+ 1 (random 255)))) strs))
-      (set! bvecs (cons (->byte-vector (make-string size (integer->char (random 256)))) bvecs))
+      (set! bvecs (cons (string->byte-vector (make-string size (integer->char (random 256)))) bvecs))
       (set! vecs (cons (make-vector size i) vecs))
       (set! ivecs (cons (make-int-vector size i) ivecs))
       (set! fvecs (cons (make-float-vector size (* i 1.0)) fvecs))
@@ -219,7 +219,7 @@
 	  (ifvec (apply vector-append ifvecs))
 	  (allvec (apply vector-append allvecs))
 	  (str (apply string-append strs))
-	  (bvec (->byte-vector (apply string-append bvecs))))
+	  (bvec (string->byte-vector (apply string-append bvecs))))
       (test (vector? vec) #t)
       (test (length vec) (* size size))
       (test (float-vector? fvec) #t)
