@@ -27,13 +27,12 @@
 		     z))))
 (define vect-3 (let ((x '(1 2)))
 		 (let ((y (list x x)))
-		   (let ((z (vector x y)))
-		     z))))
-(define vect-4 (let ((v (vector 1 2 3 4)))
-		 (let ((lst (list 1 2)))
-		   (set-cdr! (cdr lst) lst)
-		   (set! (v 0) v)
-		   (set! (v 3) lst))))
+		   (vector x y))))
+(define vect-4 (let ((v (vector 1 2 3 4))
+		     (lst (list 1 2)))
+		 (set-cdr! (cdr lst) lst)
+		 (set! (v 0) v)
+		 (set! (v 3) lst)))
 (define hash-2 (let ((h1 (make-hash-table 11)))
 		 (hash-table-set! h1 "hi" h1)))
 (define list-4 (let ()
