@@ -1,5 +1,5 @@
-(if (and (not (provided? 'snd))
-	 (not (provided? 'sndlib)))
+(if (not (or (provided? 'snd)
+	     (provided? 'sndlib)))
     (begin
       (format *stderr* "tgen depends on sndlib...~%")
       (system "./snd -noinit tgen.scm")
@@ -158,10 +158,10 @@
 ;(define vequal morally-equal?)
 
 (define-constant (checkout str V v1 v2 v3 v4 v5 v6 v7 v8 v9 v10 v11 v12)
-  (if (or (not (vequal V v1)) 
-	  (not (vequal v1 v2)) 
-	  (not (vequal v1 v3)) 
-	  (not (vequal v1 v4)))
+  (if (not (and (vequal V v1)
+		(vequal v1 v2)
+		(vequal v1 v3)
+		(vequal v1 v4)))
       (format *stderr* "~S:~%    no do:  ~A~%    fv-set: ~A~%    outa->v:~A~%    outa:   ~A~%    list:   ~A~%" str V v1 v2 v3 v4))
   (if (not (vequal v5 v6)) (format *stderr* "dox ~S:~%   fv-set: ~A~%    outa->v:~A~%" str v5 v6))
   (if (not (vequal v7 v8)) (format *stderr* "let ~S:~%    ~A~%    ~A~%" str v7 v8))
@@ -169,10 +169,10 @@
   (if (not (vequal v11 v12)) (format *stderr* "letx ~S:~%    ~A~%    ~A~%" str v11 v12)))
 
 (define-constant (checkout-1 str V v1 v2 v3 v4 v5 v6 v11 v12)
-  (if (or (not (vequal V v1)) 
-	  (not (vequal v1 v2)) 
-	  (not (vequal v1 v3)) 
-	  (not (vequal v1 v4)))
+  (if (not (and (vequal V v1)
+		(vequal v1 v2)
+		(vequal v1 v3)
+		(vequal v1 v4)))
       (format *stderr* "~S:~%    no do:  ~A~%    fv-set: ~A~%    outa->v:~A~%    outa:   ~A~%    list:   ~A~%" str V v1 v2 v3 v4))
   (if (not (vequal v5 v6)) (format *stderr* "dox ~S:~%   fv-set: ~A~%    outa->v:~A~%" str v5 v6))
   (if (not (vequal v11 v12)) (format *stderr* "letx ~S:~%    ~A~%    ~A~%" str v11 v12)))
