@@ -4,7 +4,7 @@
 		     ("tform.scm" . "v-form")
 		     ("thash.scm" . "v-hash")
 		     ("tcopy.scm" . "v-cop")
-		     ("lg.scm" . "v-lg")
+		     ;("lg.scm" . "v-lg")
 		     ("tgen.scm" . "v-gen")
 		     ("tauto.scm" . "v-auto")
 		     ("make-index.scm" . "v-index")
@@ -49,7 +49,7 @@
 	 (list "repl" "tcopy.scm")
 	 (list "repl" "tauto.scm")
 	 (list "repl" "titer.scm")
-	 (list "repl" "lg.scm")
+	 ;(list "repl" "lg.scm")
 	 (list "repl" "thash.scm")
 	 (list "snd -noinit" "tgen.scm")    ; repl here + cload sndlib was slower
 	 (list "snd -noinit" "tall.scm")
