@@ -376,18 +376,14 @@
 ;;; -------- with-mixed-sound --------
 
 (define (with-mixed-sound-mix-info id snd)
-
-  (define (find-if pred lst)
+  (let find-if ((pred (lambda (info)
+			(and (>= id (car info))
+			     (< id (+ (car info) (caddr info))))))
+		(lst (sound-property 'with-mixed-sound-info snd)))   ; each entry is '(mx-id beg chans note)
     (cond ((null? lst) #f)
 	  ((pred (car lst)) (car lst))
-	  (else (find-if pred (cdr lst)))))
+	  (else (find-if pred (cdr lst))))))
 
-  (let ((all-info (sound-property 'with-mixed-sound-info snd)))
-    ;; each entry is '(mx-id beg chans note)
-    (find-if (lambda (info)
-	       (and (>= id (car info))
-		    (< id (+ (car info) (caddr info)))))
-	     all-info)))
 
 (define-macro (with-mixed-sound args . body)
   `(let* ((output (with-sound-helper (lambda () #f) ,@args :to-snd #t)) ; pick up args for output
@@ -733,7 +729,7 @@ symbol: 'e4 for example.  If 'pythagorean', the frequency calculation uses small
 		 (octave (if octave-char (- (char->integer octave-char) (char->integer #\0)) last-octave))
 		 (base-pitch (let ((base (modulo (- (+ (char->integer (name 0)) 5) (char->integer #\a)) 7)) ; c-based (diatonic) octaves	   
 				   (sign (case sign-char ((#f) 0) ((#\f) -1) (else 1))))
-			       (+ sign (case base ((0) 0) ((1) 2) ((2) 4) ((3) 5) ((4) 7) ((5) 9) ((6) 11)))))
+			       (+ sign (case base ((0)) ((1) 2) ((2) 4) ((3) 5) ((4) 7) ((5) 9) ((6) 11)))))
 		 (et-pitch (+ base-pitch (* 12 octave))))
 	    (set! last-octave octave)
 	    (* main-pitch (if pythagorean
